@@ -2,6 +2,8 @@ var classDrawingObjectsChanger =
 [
     [ "DrawingObjectsChanger", "classDrawingObjectsChanger.html#aaf5fe3bbb3ebbec3cb8ff0f0c358c044", null ],
     [ "~DrawingObjectsChanger", "classDrawingObjectsChanger.html#a34c50899e80d0db68c7b0497e429dc22", null ],
+    [ "DrawingObjectsChanger", "classDrawingObjectsChanger.html#a2aeff9c1052fe23575550978f2aaf032", null ],
+    [ "operator=", "classDrawingObjectsChanger.html#ac78513cc82fc369d13c4866886af6ce9", null ],
     [ "m_brush", "classDrawingObjectsChanger.html#a5fbbe3d7c8277fc7a39a46d5227c0f70", null ],
     [ "m_dc", "classDrawingObjectsChanger.html#a9f006e26b396936809f5b77453b44624", null ],
     [ "m_pen", "classDrawingObjectsChanger.html#a10de9b95dfd82415875c19b2d913dc28", null ]
