@@ -2,6 +2,8 @@ var classScaler =
 [
     [ "Scaler", "classScaler.html#ad0ce2c5f515fafe3223a8e96f780701a", null ],
     [ "~Scaler", "classScaler.html#aa2a4f541259cc6cf6260f83368a1f81f", null ],
+    [ "Scaler", "classScaler.html#a3eb1f14b21d9227b1d59654906ea8539", null ],
+    [ "operator=", "classScaler.html#a08da6a2cd212fd847f0429d56db6a857", null ],
     [ "m_dc", "classScaler.html#a59bf721f4717c535c13889518b18efd6", null ],
     [ "m_xScaleOld", "classScaler.html#a1e60600170c92a4669e533276c478e40", null ],
     [ "m_yScaleOld", "classScaler.html#a2b833d6ba6585e0902a8a85c19fdf830", null ]
