@@ -9,7 +9,7 @@ var classplstream =
     [ "plstream", "classplstream.html#a56a016565198f4cd1c04a6a1b860234c", null ],
     [ "~plstream", "classplstream.html#a5af59482d375dff51d99f49715d5888a", null ],
     [ "adv", "classplstream.html#ab7f5e5c91c441fc52d4e19289780a2b2", null ],
-    [ "Alloc2dGrid", "classplstream.html#aa5552169469a3f9cc841311b13272992", null ],
+    [ "Alloc2dGrid", "classplstream.html#aa140f00e5046b418d58a626234f1f263", null ],
     [ "arc", "classplstream.html#a2df216bc3bcfb93557a580f9db97d31c", null ],
     [ "axes", "classplstream.html#aae9c3ed421ec29c56c6a1ea0767ea0d4", null ],
     [ "bin", "classplstream.html#aad778bc5fa73b64be84fa815ef5e755c", null ],
@@ -22,14 +22,12 @@ var classplstream =
     [ "ClearOpts", "classplstream.html#a3921c12c03ad654e354bbba07a6c57eb", null ],
     [ "cmd", "classplstream.html#a0aed09ebde7556077e59ecba2af1b2a8", null ],
     [ "col", "classplstream.html#a814d3ed5c7a45bdc5359e252bee5b6c7", null ],
-    [ "col", "classplstream.html#a145a04d677fb3192e3eb90846949e693", null ],
     [ "col0", "classplstream.html#a6cde7180bbc3ab9e10d3a4f4439bd785", null ],
     [ "col1", "classplstream.html#a943581cf5af193483948da880ee58f2e", null ],
     [ "colorbar", "classplstream.html#a9364f32b836a2b176a7f05101238f501", null ],
     [ "configtime", "classplstream.html#a46ecf82c5d6c6da684f6143c650b698c", null ],
     [ "cont", "classplstream.html#abebc7506ac6888b4956464b471a3df89", null ],
     [ "cpstrm", "classplstream.html#ab24f6d2d81f77b70cc8c2ca34c38973c", null ],
-    [ "cpstrm", "classplstream.html#ac13e957141a49f30c8c659193d17446c", null ],
     [ "ctime", "classplstream.html#a60956f9ea224e1007f85ef218166fc4f", null ],
     [ "did2pc", "classplstream.html#a391ce788e59848110b661569d4b1e2c4", null ],
     [ "dip2dc", "classplstream.html#a97f3fef8272ba076824a93fd038f9b92", null ],
@@ -52,7 +50,6 @@ var classplstream =
     [ "fontld", "classplstream.html#a95cefa0ee7ebe5df2dba2b07f508d78f", null ],
     [ "Free2dGrid", "classplstream.html#a5dd0b25c877c8c6ed472ce987489cdf8", null ],
     [ "fshade", "classplstream.html#a389c321002d05e5f79eade2253ec2622", null ],
-    [ "fshade", "classplstream.html#ab1b8de1e014a32cfd23fa43cb1ffe994", null ],
     [ "gchr", "classplstream.html#ae7efc7ade952636c6abe4aa0f7d4546a", null ],
     [ "gcmap1_range", "classplstream.html#ad33d6f819a27a64e0f78458bcee80064", null ],
     [ "gcol0", "classplstream.html#aba4cd52aa9af674333751cfd4c3e1f0e", null ],
@@ -108,23 +105,20 @@ var classplstream =
     [ "meridians", "classplstream.html#a7c73766685da5f70691167e6ea3870d5", null ],
     [ "mesh", "classplstream.html#aef940236ed0723c5d3342f1f443e1584", null ],
     [ "meshc", "classplstream.html#a6057782840bab5084eb82bbd06e44762", null ],
-    [ "MinMax2dGrid", "classplstream.html#a4a3ab3867339920a1ed1fc4456d0be3b", null ],
+    [ "MinMax2dGrid", "classplstream.html#ac7590a37329e76bc1877a9b6a624d8af", null ],
     [ "mtex", "classplstream.html#a275d45c168a620a9636c80039507db6a", null ],
     [ "mtex3", "classplstream.html#a44b5a3743d67214ea3f81f198faadd9e", null ],
     [ "operator=", "classplstream.html#a2dbfc7548479908d27dab94893aacae1", null ],
     [ "OptUsage", "classplstream.html#af54356617be65cdf161918e3430321df", null ],
     [ "parseopts", "classplstream.html#a83fb619e15efeb67b76b6ff4737a750b", null ],
-    [ "ParseOpts", "classplstream.html#aba71197c02ab2bad417a0a7c20cc9256", null ],
     [ "pat", "classplstream.html#a53df0e65b853f901c0ece2bc910ecb93", null ],
     [ "path", "classplstream.html#ac67651bdb28405cfa204c342901aa5c1", null ],
     [ "plot3d", "classplstream.html#a41ca966d482620a54c58d57365283abe", null ],
-    [ "plot3d", "classplstream.html#a5ae79dcb98a8aee3a1df1f45952a756f", null ],
     [ "plot3dc", "classplstream.html#af1b96858211dce025c64fb0b5a84d7fe", null ],
     [ "plot3dcl", "classplstream.html#ac8749d7e1682f59e380c78923ad6c49f", null ],
     [ "poin", "classplstream.html#a9f55e53eb2a0174e53dd4f3d3856ef12", null ],
     [ "poin3", "classplstream.html#a78128eb2e5a20aff41e9450d6b1db5c1", null ],
     [ "poly3", "classplstream.html#acfba92fa1b426a04592e3517cf4dff95", null ],
-    [ "poly3", "classplstream.html#a87034dcbf5dcba51a4bb344a2df18cb4", null ],
     [ "prec", "classplstream.html#a7a117b27a8c4d9edba33224e92939591", null ],
     [ "psty", "classplstream.html#a56ddd5bba6e2e044225c98692d6b5d36", null ],
     [ "ptex", "classplstream.html#ab06ceccd61a62e4d0a5e11452094cfdd", null ],
@@ -142,7 +136,6 @@ var classplstream =
     [ "scmap1_range", "classplstream.html#ac82b4378ed491f20571ff42987ba3325", null ],
     [ "scmap1a", "classplstream.html#a1f0afae15c66fb06e3aabd7901519502", null ],
     [ "scmap1l", "classplstream.html#a6ce468b17faf6fefeb1e22921a230be0", null ],
-    [ "scmap1l", "classplstream.html#acc1a8b8491609bc7eb58dd3f8357e660", null ],
     [ "scmap1la", "classplstream.html#ad7b1d5173bb09c358411e07b5c64b133", null ],
     [ "scmap1n", "classplstream.html#a6d85337661f8b9797d2ee75758d87179", null ],
     [ "scol0", "classplstream.html#a3b8ae477ba529bd6963919571c0be9b1", null ],
@@ -176,12 +169,7 @@ var classplstream =
     [ "sfont", "classplstream.html#a91fb74d3049cfc5aee44aa4c79d91fa5", null ],
     [ "shade", "classplstream.html#a4574ee31c09ee2b6adf7c7e56d564d6a", null ],
     [ "shade", "classplstream.html#a304a4d2f030a260d1eda23146f071a00", null ],
-    [ "shade", "classplstream.html#ac6aff5065eef8740034ddc39df1f7df5", null ],
-    [ "shade", "classplstream.html#ab293e3076025f0af92e5232366ff828f", null ],
-    [ "shade1", "classplstream.html#accfa85c8e9d7f9428bda763f837f2b59", null ],
-    [ "shade1", "classplstream.html#a540c6676572ec2d21dbffed321403656", null ],
     [ "shades", "classplstream.html#adde882d5199742454da45d18420c601a", null ],
-    [ "shades", "classplstream.html#a6fe4b00507719a61ec9cc70eed43bfd2", null ],
     [ "sKeyEH", "classplstream.html#a98fe43bcaec074c698e7baa82d1af422", null ],
     [ "slabelfunc", "classplstream.html#aa0b69eeeeefa7f4a71184001f8b946c0", null ],
     [ "smaj", "classplstream.html#ac4af1ef0006205c87c77f075fa29d520", null ],
@@ -193,24 +181,22 @@ var classplstream =
     [ "spal0", "classplstream.html#a04f0cb933006bf6700acf8bcab2f2658", null ],
     [ "spal1", "classplstream.html#a855bdc0dc9a8d6cbfa79c602d34b8346", null ],
     [ "spause", "classplstream.html#adced3758bc250a1cb2ce22eceef005d2", null ],
-    [ "spause", "classplstream.html#a4544aba52d4c8095f9cdceb32f4a70a6", null ],
     [ "sstrm", "classplstream.html#a126cddeb3f33eb23e49399b2422faaf6", null ],
     [ "ssub", "classplstream.html#aa154ccc662e42b8914d1ccb5c1b79025", null ],
     [ "ssym", "classplstream.html#a897b309e307033532093edabb14d3d7c", null ],
     [ "star", "classplstream.html#a3e4314ad8f9e2c52d230562a51b001a8", null ],
     [ "start", "classplstream.html#af9ae28094f4dc1630bf8cdfdf834f374", null ],
+    [ "Static2dGrid", "classplstream.html#a46fbb635ebc7f9dd439c3f17ad354210", null ],
     [ "stransform", "classplstream.html#a1d5189f44e2c78db6f39a1ab28ad6ea6", null ],
     [ "string", "classplstream.html#a67cf3bbe5ada1e44014bb669845ccc9d", null ],
     [ "string3", "classplstream.html#ae1a113fa6fd26bf4d6d712f545f0eb3d", null ],
     [ "stripa", "classplstream.html#a8f2e30bdaaa11336b45432a2169b3027", null ],
     [ "stripc", "classplstream.html#acdee31e840663387b6670597f658d533", null ],
-    [ "stripc", "classplstream.html#a009d03c2c8fb391458bdecc8012b1870", null ],
     [ "stripd", "classplstream.html#a5c75ee6c39722e68ce3d4353ea8d8c3e", null ],
     [ "styl", "classplstream.html#a99bfa28534e367d7231b6521e1e2261c", null ],
     [ "surf3d", "classplstream.html#ad62c88c23bedfd3ecbf63ba2d9e1279c", null ],
     [ "surf3dl", "classplstream.html#adb6431e447f249687a3b76a08e58e27f", null ],
     [ "svect", "classplstream.html#abb015cff1f650cc88414a2eb8eb45584", null ],
-    [ "svect", "classplstream.html#a7304e14dc62922e49b3bbd9255208f1b", null ],
     [ "svpa", "classplstream.html#a26e8905fbe594ff2f64949918972fbf6", null ],
     [ "sxax", "classplstream.html#a8844b2f8a416aca783b7da4b65066031", null ],
     [ "sxwin", "classplstream.html#a752fa6e2837a2fea7015cc95f67d3e62", null ],
@@ -229,7 +215,6 @@ var classplstream =
     [ "width", "classplstream.html#a7a993bd850c9dc8d7f3fab51b544c778", null ],
     [ "wind", "classplstream.html#a01d10b709219154e2cd6f7d8920ba95d", null ],
     [ "xormod", "classplstream.html#ab338a30331e3e8fb4254e8599ec9fe42", null ],
-    [ "xormod", "classplstream.html#a2a66abc85c097f2a59d3902aaf336a8f", null ],
     [ "active_streams", "classplstream.html#a40c5a40e609b74ef8b1046da85edf495", null ],
     [ "stream", "classplstream.html#a8842149487ed8a785601f2ecfb66f818", null ]
 ];
\ No newline at end of file
