@@ -13,6 +13,7 @@ var functions_func =
     [ "j", "functions_func_j.html", null ],
     [ "l", "functions_func_l.html", null ],
     [ "m", "functions_func_m.html", null ],
+    [ "n", "functions_func_n.html", null ],
     [ "o", "functions_func_o.html", null ],
     [ "p", "functions_func_p.html", null ],
     [ "q", "functions_func_q.html", null ],
@@ -22,5 +23,5 @@ var functions_func =
     [ "v", "functions_func_v.html", null ],
     [ "w", "functions_func_w.html", null ],
     [ "x", "functions_func_x.html", null ],
-    [ "~", "functions_func_~.html", null ]
+    [ "~", "functions_func_0x7e.html", null ]
 ];
\ No newline at end of file
