@@ -6,7 +6,7 @@ var searchData=
   ['xdigmax',['xdigmax',['../structPLStream.html#abe70e4b3e2130f7a25e67c9b49c70ad8',1,'PLStream']]],
   ['xdpi',['xdpi',['../structPLStream.html#a2d24d9a093f447144c8f3ea9cac2d349',1,'PLStream']]],
   ['xfig_2ec',['xfig.c',['../xfig_8c.html',1,'']]],
-  ['xform',['xform',['../structEscText.html#ae0f4c1c790597d359c13f35ea409670c',1,'EscText::xform()'],['../classCoord__Xformer.html#abd478464102004b5f9a486d816ad525f',1,'Coord_Xformer::xform()'],['../classcxx__pltr2.html#ac7a061b153de8157c25a36f0a8f4f1a5',1,'cxx_pltr2::xform()'],['../plplot__octaveOCTAVE__wrap_8cxx.html#acf5309370447410efcc2382acbb597cc',1,'xform():&#160;plplot_octaveOCTAVE_wrap.cxx']]],
+  ['xform',['xform',['../structEscText.html#ae0f4c1c790597d359c13f35ea409670c',1,'EscText::xform()'],['../classCoord__Xformer.html#abd478464102004b5f9a486d816ad525f',1,'Coord_Xformer::xform()'],['../classcxx__pltr2.html#adec6eb37017ee7ba1907fba28c0fae01',1,'cxx_pltr2::xform()'],['../plplot__octaveOCTAVE__wrap_8cxx.html#acf5309370447410efcc2382acbb597cc',1,'xform():&#160;plplot_octaveOCTAVE_wrap.cxx']]],
   ['xg',['xg',['../classcxx__pltr2.html#a07b70acf43c8223b95d27e3792cfc0cd',1,'cxx_pltr2::xg()'],['../structplplot_1_1PLcGrid.html#ab79e29e9d6066868e145323ab8b2e1c7',1,'plplot::PLcGrid::xg()'],['../structplplot_1_1PLcGrid2.html#a7c45933d67e0b15ee227f39cebcb57d5',1,'plplot::PLcGrid2::xg()'],['../structplplot_1_1__N7.html#af0c3ecbae3e12785c6c7334840faf618',1,'plplot::_N7::xg()'],['../structplplot_1_1__N8.html#a1404ed8d26b06cbd800674449623c973',1,'plplot::_N8::xg()'],['../structplplot__types_1_1plcgrid.html#aa52fb86071bfce2288e184ba5dd836da',1,'plplot_types::plcgrid::xg()'],['../structPLcGrid.html#a1c5faea0b8b710068908a6550c638e97',1,'PLcGrid::xg()'],['../structPLcGrid2.html#a5dc6e0ee10871fbbe5594c7a5ee41cff',1,'PLcGrid2::xg()']]],
   ['xgradient',['xgradient',['../structPLStream.html#a962465c1e71ed607052e2a1e36d0b4b5',1,'PLStream']]],
   ['xhair_5fcursor',['xhair_cursor',['../structPlFrame.html#a318fb1957be2cf5100382b63b70a430c',1,'PlFrame::xhair_cursor()'],['../structPlPlotter.html#a8038e60689df995da5850b9e55b2aaf0',1,'PlPlotter::xhair_cursor()'],['../structTkwDisplay.html#a6139c89bf30f02dfff34f03c61689e83',1,'TkwDisplay::xhair_cursor()'],['../structXwDisplay.html#a6552c5aaf33176576a63e04d1aaaf1c2',1,'XwDisplay::xhair_cursor()']]],
@@ -26,10 +26,10 @@ var searchData=
   ['xmax_5fdev',['xmax_dev',['../structPLDev.html#a8d33f07b5696b26dbe2ed8648cbeec93',1,'PLDev::xmax_dev()'],['../structPSDev.html#a50af04cad55e158e195fe0d96029bdba',1,'PSDev::xmax_dev()']]],
   ['xmin',['xmin',['../structcsa.html#a005399c1a1a23bcf46c2f4ed3acc70bd',1,'csa::xmin()'],['../structdelaunay.html#adfaa7a8743255547db60acdf55a90b96',1,'delaunay::xmin()'],['../structPLStrip.html#a952a2f41f34f9295ad7c29c9fc2ea950',1,'PLStrip::xmin()'],['../structPLRDev.html#adc1db0719f2952bc0152fc50c2e50302',1,'PLRDev::xmin()'],['../structPLmDev.html#aebd0f535a8753477736ffcf8302e0e2f',1,'PLmDev::xmin()'],['../structIMG__DT.html#a2a967ce77593f3362dda17c0c7385ff9',1,'IMG_DT::xmin()'],['../structPLDev.html#aff0304a2dcc0db26abbec401b5eb25c6',1,'PLDev::xmin()'],['../structPSDev.html#a726f94977509580d43eec85fb5d30f59',1,'PSDev::xmin()'],['../ps_8h.html#a6aee779504f876f9bed834f36b392da9',1,'XMIN():&#160;ps.h']]],
   ['xmin_5fdev',['xmin_dev',['../structPLDev.html#a4be70c9c75177f43ac2500903dfde560',1,'PLDev::xmin_dev()'],['../structPSDev.html#add0168298b323516c82e0bc4bc13983b',1,'PSDev::xmin_dev()']]],
-  ['xoffset',['xOffset',['../classQtPLDriver.html#aa5459c458d794c0536fdde23d059406d',1,'QtPLDriver::xOffset()'],['../structPLStream.html#a59aa7205e849ddd9b67c95420bf3bffe',1,'PLStream::xoffset()'],['../ps_8h.html#a5839ff01cf736fc8624e4780336622bd',1,'XOFFSET():&#160;ps.h']]],
+  ['xoffset',['xoffset',['../structPLStream.html#a59aa7205e849ddd9b67c95420bf3bffe',1,'PLStream::xoffset()'],['../classQtPLDriver.html#aa5459c458d794c0536fdde23d059406d',1,'QtPLDriver::xOffset()'],['../ps_8h.html#a5839ff01cf736fc8624e4780336622bd',1,'XOFFSET():&#160;ps.h']]],
   ['xold',['xold',['../structPLRDev.html#a1b93a8aba2e97f23d7b031a5a224baed',1,'PLRDev::xold()'],['../structTkDev.html#a73901cd7a8e8278fc8dd96f2a1fcbeb6',1,'TkDev::xold()'],['../structPLmDev.html#aef98ee70a88c95f339a4f32b9bd38468',1,'PLmDev::xold()'],['../structPLDev.html#ab71f661ba3049e35e4ee427050d25b10',1,'PLDev::xold()'],['../structPSDev.html#a9753ff4a7c6ea93ba7ea8fca2cf67462',1,'PSDev::xold()']]],
   ['xorgc',['xorGC',['../structPlFrame.html#a3c44e36073bc6376f90f5fcbe4b87fab',1,'PlFrame::xorGC()'],['../structPlPlotter.html#a343431d349fd3ae0f118fc3773144c17',1,'PlPlotter::xorGC()']]],
-  ['xormod',['xormod',['../classplstream.html#ab338a30331e3e8fb4254e8599ec9fe42',1,'plstream::xormod(bool mode, bool *status)'],['../classplstream.html#a2a66abc85c097f2a59d3902aaf336a8f',1,'plstream::xormod(PLINT mode, PLINT *status)']]],
+  ['xormod',['xormod',['../classplstream.html#ab338a30331e3e8fb4254e8599ec9fe42',1,'plstream']]],
   ['xpmm',['xpmm',['../structPLStream.html#af2865bcc032aafba071341ba183d6c39',1,'PLStream']]],
   ['xpssize',['XPSSIZE',['../ps_8h.html#a410ceac53c3a66ef5002d3d48fde9558',1,'ps.h']]],
   ['xr',['xr',['../structPlFrame.html#ae0703e81c08538367597a73dd4c5ace5',1,'PlFrame::xr()'],['../structPlPlotter.html#ab59fc3646770e4ea56d07cc6571738d5',1,'PlPlotter::xr()']]],
