@@ -21,7 +21,7 @@ var searchData=
   ['base',['base',['../structEscText.html#a27f50fc8ce09a219b990abc6959073e1',1,'EscText::base()'],['../structswig__octave__class.html#ac6a03dae555a63dbc7751aa1dc1c9e55',1,'swig_octave_class::base()']]],
   ['base3x',['base3x',['../structPLStream.html#a7668dd6c3144f760c74d391fb53accbe',1,'PLStream']]],
   ['base3y',['base3y',['../structPLStream.html#ac6604eb5ffb1439c89b1f40c812f7468',1,'PLStream']]],
-  ['base_5fcont',['BASE_CONT',['../classplplot.html#a8ad02f0abe82b2c26d28a9ea608e21c6',1,'plplot::BASE_CONT()'],['../plplot_8h.html#a615d5bba089363ae37df2a6b33fac010',1,'BASE_CONT():&#160;plplot.h'],['../namespaceplplotc.html#a8ad0cfa320c20249a5672441c5d41833',1,'plplotc.BASE_CONT()'],['../namespaceplplotc__fixed.html#a0f58697657dff4a4f2ce452f58dc330e',1,'plplotc_fixed.BASE_CONT()']]],
+  ['base_5fcont',['BASE_CONT',['../plplot_8h.html#a615d5bba089363ae37df2a6b33fac010',1,'BASE_CONT():&#160;plplot.h'],['../namespaceplplot.html#a8ad02f0abe82b2c26d28a9ea608e21c6',1,'plplot::BASE_CONT()'],['../namespaceplplotc.html#a69b69bb3044b3fb83c14f09561cb1cf7',1,'plplotc.BASE_CONT()']]],
   ['base_5fday',['base_day',['../structMJDtimeStruct.html#a7a7b02e1fc6ffee218d9ae1b4ad76f18',1,'MJDtimeStruct::base_day()'],['../structTAI__UTC.html#a86a46f8d5627f742cdbd14b0a8d64eae',1,'TAI_UTC::base_day()']]],
   ['base_5fnames',['base_names',['../structswig__lua__class.html#a25f24829385c30c59cec92c91fceca23',1,'swig_lua_class::base_names()'],['../structswig__octave__class.html#a4045c37af980b6aeeb76bc508f1a7560',1,'swig_octave_class::base_names()']]],
   ['basecx',['basecx',['../structPLStream.html#a1cfe7c5e03bfc0b86f2b7890cbc89f18',1,'PLStream']]],
@@ -31,7 +31,7 @@ var searchData=
   ['beginpage',['BeginPage',['../classPlDevice.html#a08516c6db27c87020d3b0fccd13231e7',1,'PlDevice::BeginPage()'],['../classwxPLDevice.html#a908760e63e954c0b5aadc093c8f9e9ef',1,'wxPLDevice::BeginPage()']]],
   ['betw',['BETW',['../plplotP_8h.html#af6c78f36cb8594e9612e7acbcf28e8bb',1,'plplotP.h']]],
   ['betw_5fnbcc',['BETW_NBCC',['../plfill_8c.html#a660527944420239471220a0bfec4c5e2',1,'plfill.c']]],
-  ['bgcolor',['bgcolor',['../structXwDev.html#aa175f8852cb1e51b9a7a93a842db0dab',1,'XwDev::bgcolor()'],['../structPlFrame.html#a0a649d61c2f65a42fc3451c6c850293d',1,'PlFrame::bgColor()']]],
+  ['bgcolor',['bgColor',['../structPlFrame.html#a0a649d61c2f65a42fc3451c6c850293d',1,'PlFrame::bgColor()'],['../structXwDev.html#aa175f8852cb1e51b9a7a93a842db0dab',1,'XwDev::bgcolor()']]],
   ['bhunt_5fsearch',['bhunt_search',['../qsastime_8c.html#ac4ecc71b746168056d0c2ac611504452',1,'bhunt_search(const void *key, const void *base, int n, size_t size, int *low, int(*ge)(const void *keyval, const void *datum)):&#160;qsastime.c'],['../qsastimeP_8h.html#a4023570fb0c462f766569147984ea58b',1,'bhunt_search(const void *key, const void *base, int n, size_t size, int *low, int(*ge)(const void *keyval, const void *datum)):&#160;qsastime.c']]],
   ['bhunt_5fsearch_5ftest_2ec',['bhunt_search_test.c',['../bhunt__search__test_8c.html',1,'']]],
   ['big_5frecl',['big_recl',['../plshade_8c.html#af0b5c0ec2e072e4bdca795e20a09f7d7',1,'plshade.c']]],
@@ -47,7 +47,7 @@ var searchData=
   ['bop',['bop',['../classplstream.html#ae06d098b31cd579cd41d81f5db1c6be8',1,'plstream::bop()'],['../metadefs_8h.html#a857adfef718262ca4a28b3648c56de5c',1,'BOP():&#160;metadefs.h']]],
   ['bop0',['BOP0',['../metadefs_8h.html#a7602e5c62ddc385d9df6c96b898f889f',1,'metadefs.h']]],
   ['bop_5fdata',['bop_data',['../structPLStream.html#ad60fe1add202f6c12ee8f6e3f4546962',1,'PLStream']]],
-  ['bop_5fhandler',['bop_handler',['../structPLStream.html#a570753f4964edc378661c79b56da7458',1,'PLStream']]],
+  ['bop_5fhandler',['bop_handler',['../structPLStream.html#a26c8a1f3efd41ea03060695a8eb2df5b',1,'PLStream']]],
   ['bopcmd',['bopCmd',['../structPlFrame.html#a0015cea9695cf72b89638874148148b2',1,'PlFrame::bopCmd()'],['../structPlPlotter.html#a6e828a8cb52aaad71314661f2cab39d3',1,'PlPlotter::bopCmd()']]],
   ['border',['border',['../structPlFrame.html#ae6cd88baa34aa30ef958d96c5a399336',1,'PlFrame::border()'],['../structPlPlotter.html#a7b947ac76bd574078c465ebf457611d0',1,'PlPlotter::border()'],['../structTkwDev.html#a4cc81954b003b8bfa80c4b4dcfe9f051',1,'TkwDev::border()'],['../structXwDev.html#a566d91035d635b24101552997b479bd5',1,'XwDev::border()']]],
   ['borderwidth',['borderWidth',['../structPlFrame.html#a88adc0ded0381397e89b8f28ab8a68ff',1,'PlFrame::borderWidth()'],['../structPlPlotter.html#a5e53528a880abb2eeba413e7bd370272',1,'PlPlotter::borderWidth()']]],
@@ -73,8 +73,8 @@ var searchData=
   ['bufsize',['BUFSIZE',['../nncommon_8c.html#aeca034f67218340ecb2261a22c2f3dcd',1,'nncommon.c']]],
   ['build_5fdir',['BUILD_DIR',['../plplot__config_8h.html#a40ae373788da1701b1df883e62b46373',1,'plplot_config.h']]],
   ['buildlist',['buildlist',['../plfill_8c.html#a10842154848df7e58bfe1b0698082edd',1,'buildlist(PLINT, PLINT, PLINT, PLINT, PLINT, PLINT, PLINT):&#160;plfill.c'],['../plfill_8c.html#a1db96be13602134cdb90815f0f14aae0',1,'buildlist(PLINT xp1, PLINT yp1, PLINT xp2, PLINT yp2, PLINT PL_UNUSED(xp3), PLINT yp3, PLINT dinc):&#160;plfill.c']]],
-  ['button',['button',['../structplplot_1_1__N2.html#a05930baa71b889a734634b1f29df5bec',1,'plplot::_N2::button()'],['../structplplot__graphics_1_1plgraphicsin.html#aa3e888f600b88cc67f344cda61e8d3bd',1,'plplot_graphics::plgraphicsin::button()'],['../structPLGraphicsIn.html#ae17f938017e1c95e5d8cd89ffa836934',1,'PLGraphicsIn::button()']]],
-  ['buttoneh',['ButtonEH',['../structPLStream.html#a4e9b2af1783d70f3958424b2ebd2b6e1',1,'PLStream']]],
+  ['button',['button',['../structplplot_1_1__N2.html#a05930baa71b889a734634b1f29df5bec',1,'plplot::_N2::button()'],['../structplplot__graphics_1_1plgraphicsin.html#aa3e888f600b88cc67f344cda61e8d3bd',1,'plplot_graphics::plgraphicsin::button()'],['../structPLGraphicsIn.html#ae17f938017e1c95e5d8cd89ffa836934',1,'PLGraphicsIn::button()'],['../classplplotc_1_1PLGraphicsIn.html#af94b51a13660df83880f29d594d0ea03',1,'plplotc.PLGraphicsIn.button()']]],
+  ['buttoneh',['ButtonEH',['../structPLStream.html#ac8f51f07b6f9ebd5d22b0a026867c31a',1,'PLStream']]],
   ['buttoneh_5fdata',['ButtonEH_data',['../structPLStream.html#a0ebf6193b59ba88317034f0f5421a7cf',1,'PLStream']]],
   ['bytecnt',['bytecnt',['../structPLStream.html#a2bae14e39334897df7684da4a7d319fe',1,'PLStream']]],
   ['bytemax',['bytemax',['../structPLStream.html#afa8cd5d4c8ac54d5308dc548991a3fee',1,'PLStream']]],
