@@ -29,10 +29,11 @@ var searchData=
   ['genrand_5fres53',['genrand_res53',['../mt19937ar_8c.html#ac821d41970276e53e85bde08b24536b8',1,'genrand_res53(void):&#160;mt19937ar.c'],['../mt19937ar_8h.html#ac821d41970276e53e85bde08b24536b8',1,'genrand_res53(void):&#160;mt19937ar.c']]],
   ['geometry',['geometry',['../structPLStream.html#a7844488c645193fee1f5e1f31df9798e',1,'PLStream::geometry()'],['../tkMain_8c.html#a3512ed15de220f178dc26334564c6463',1,'geometry():&#160;tkMain.c']]],
   ['gesc',['gesc',['../classplstream.html#a4cdd16f2533213fef5cd5d18358af469',1,'plstream']]],
-  ['get',['get',['../structtclMatrix.html#a33d2abf4f0d6e86fcfdf32a333265b12',1,'tclMatrix::get()'],['../structplf2ops__t.html#a5e06163958c53e58712d8a76d6918b40',1,'plf2ops_t::get()'],['../structswig__lua__var__info.html#a56fb0b689f37015e340b35c6d7ee0b99',1,'swig_lua_var_info::get()']]],
-  ['get_5fattr',['get_attr',['../structswig__globalvar.html#a051e346d0cd7608bf99e96726022e88c',1,'swig_globalvar']]],
+  ['get',['get',['../structtclMatrix.html#a1f07da9a87e675b7349e09253dcafbce',1,'tclMatrix::get()'],['../structplf2ops__t.html#a3d2ca85ae97972e8b4d6e0221aaedc27',1,'plf2ops_t::get()'],['../structswig__lua__var__info.html#a56fb0b689f37015e340b35c6d7ee0b99',1,'swig_lua_var_info::get()']]],
+  ['get_5fattr',['get_attr',['../structswig__globalvar.html#ab617d0ca02f7660a9e5fd31dceaf6475',1,'swig_globalvar']]],
   ['get_5fcharacter_5for_5fsymbol_5fheight',['get_character_or_symbol_height',['../pllegend_8c.html#aec07c6350dac714def00998097602825',1,'pllegend.c']]],
   ['get_5fcursor',['get_cursor',['../aqt_8c.html#a283273d4ad67a6e5f6d701232243fde8',1,'aqt.c']]],
+  ['get_5ffont',['get_font',['../ps_8c.html#a2c1f6499446d1f656afb4e58422467d3',1,'ps.c']]],
   ['get_5fline_5fproperties',['get_line_properties',['../cairo_8c.html#a6fd98a3dd9c44e539ca2bcaf5fe15e8a',1,'cairo.c']]],
   ['get_5fmethod',['get_method',['../structswig__octave__member.html#afc6d3dc3d5c938d5a29f53fb7237ea5a',1,'swig_octave_member']]],
   ['get_5fml_5fdefined_5ffunc',['get_ml_defined_func',['../plplot__impl_8c.html#ad6a6ceeee3ec4d3e2ef899f7547add3b',1,'plplot_impl.c']]],
@@ -40,7 +41,7 @@ var searchData=
   ['get_5fml_5fplotter_5ffunc',['get_ml_plotter_func',['../plplot__impl_8c.html#aff49a95f82ee900861be816b4a1ba580',1,'plplot_impl.c']]],
   ['get_5fmode',['get_mode',['../cairo_8c.html#a9e55fca8c85f59c5f4ad2be0b5f6e608',1,'cairo.c']]],
   ['get_5fncoords',['get_ncoords',['../plr_8c.html#ae58b9982d2450cb06989402afaaefac9',1,'plr.c']]],
-  ['get_5fptr',['get_ptr',['../classoctave__swig__ref.html#a09c386829786d99a3e98a302907a4af2',1,'octave_swig_ref']]],
+  ['get_5fptr',['get_ptr',['../classoctave__swig__ref.html#ade76da447bc44120acbed8fda510bbde',1,'octave_swig_ref']]],
   ['get_5fstring_5flength',['get_string_length',['../structPLStream.html#a97ec49d30120b332e4f9246019bc9800',1,'PLStream']]],
   ['get_5fsubpage_5fper_5fmm',['get_subpage_per_mm',['../pllegend_8c.html#a0b06baad6dbba8da07252a12887eb264',1,'pllegend.c']]],
   ['get_5ftmpdir_5flist',['get_tmpdir_list',['../plstdio_8c.html#ad77dd0fafc6ef3e40bc40cd70988e843',1,'plstdio.c']]],
@@ -52,9 +53,9 @@ var searchData=
   ['getdiffdays',['getDiffDays',['../qsastime__extra_8c.html#a3a2386ce303e6e23bc9874357c63b661',1,'getDiffDays(MJDtime *MJD1, MJDtime *MJD2):&#160;qsastime_extra.c'],['../qsastime__extra_8h.html#a0d34b04119c9aea514bc2ca4ddcc3c19',1,'getDiffDays(MJDtime *MJD1, MJDtime *MJD2):&#160;qsastime_extra.c']]],
   ['getdiffsecs',['getDiffSecs',['../qsastime__extra_8c.html#a88513dd1ed5052962e2673c7bb1d795b',1,'getDiffSecs(MJDtime *MJD1, MJDtime *MJD2):&#160;qsastime_extra.c'],['../qsastime__extra_8h.html#aebe42446e2eccd74de3642bff4d7b598',1,'getDiffSecs(MJDtime *MJD1, MJDtime *MJD2):&#160;qsastime_extra.c']]],
   ['getentries',['GetEntries',['../tclAPI_8c.html#ac277fc1a34456aa0621c7692d08163b9',1,'tclAPI.c']]],
-  ['getfci',['getFci',['../classFont.html#a35ff6bceaa08ed984a5063de0b3527f6',1,'Font']]],
+  ['getfci',['getFci',['../classFont.html#a16e39a83e4dcbad4f51c86058c072719',1,'Font']]],
   ['getflt',['GetFlt',['../classplstream.html#a54d547e04f4085121c578812f1d08d73',1,'plstream']]],
-  ['getfont',['GetFont',['../classFontGrabber.html#aa5d8a0c836830353b6ba3dd087a2bc82',1,'FontGrabber::GetFont()'],['../classQtPLDriver.html#af6aa0701912852005242921dc1442692',1,'QtPLDriver::getFont()']]],
+  ['getfont',['getFont',['../classQtPLDriver.html#af6aa0701912852005242921dc1442692',1,'QtPLDriver::getFont()'],['../classFontGrabber.html#aa5d8a0c836830353b6ba3dd087a2bc82',1,'FontGrabber::GetFont()']]],
   ['getint',['GetInt',['../classplstream.html#a4209524d70561e0054aa26e5b72ec015',1,'plstream']]],
   ['getisostring',['getISOString',['../qsastime__extra_8c.html#a18f69f8819a7d88656b4282b836e5661',1,'getISOString(MJDtime *MJD, int delim, int forceJulian):&#160;qsastime_extra.c'],['../qsastime__extra_8h.html#afc7d4c59c22310fd34e4abf593397d41',1,'getISOString(MJDtime *MJD, int delim, int forceJulian):&#160;qsastime_extra.c']]],
   ['getjd',['getJD',['../qsastime__extra_8c.html#a9f4ba0f2368287c745120b6b203404da',1,'getJD(MJDtime *MJD):&#160;qsastime_extra.c'],['../qsastime__extra_8h.html#ab7aa2822452eccd54460687c944c0d39',1,'getJD(MJDtime *MJD):&#160;qsastime_extra.c']]],
@@ -65,11 +66,11 @@ var searchData=
   ['getmonth',['getMonth',['../qsastime_8c.html#abd41112517c181424c476bd0469ac728',1,'getMonth(int m):&#160;qsastime.c'],['../qsastimeP_8h.html#a2574e380fe47645e34dcf7792d3b8bf1',1,'getMonth(int m):&#160;qsastime.c']]],
   ['getname',['GetName',['../classplstream.html#a873c02ff3dcaa3b56633f9eeeee92b9e',1,'plstream']]],
   ['getoptarg',['GetOptarg',['../plargs_8c.html#a4c5db4585b13da0514f1bb55231bec31',1,'plargs.c']]],
-  ['getsize',['getSize',['../classFont.html#a54748c2a034aaf74b5f715cb8a65980d',1,'Font::getSize()'],['../classPLMemoryMap.html#a63d96bc4208678d6b9f0289140fbce50',1,'PLMemoryMap::getSize()']]],
+  ['getsize',['getSize',['../classFont.html#a91ec5bc2045ad4cb4c02598d8c1a9164',1,'Font::getSize()'],['../classPLMemoryMap.html#a63d96bc4208678d6b9f0289140fbce50',1,'PLMemoryMap::getSize()']]],
   ['getsquares',['getsquares',['../csa_8c.html#af7faa5d6360bdf5ae2fee6a9febd4ea3',1,'csa.c']]],
   ['getstream',['GetStream',['../classwxPLplotwindow.html#ad9d61ecc3ec9276be73cc89ce7a1b1aa',1,'wxPLplotwindow']]],
   ['gettextpicture',['getTextPicture',['../classQtPLDriver.html#a6ba3d708c1155e63468b51c010466d12',1,'QtPLDriver']]],
-  ['getunderlined',['getUnderlined',['../classFont.html#ab4bb88868bcca9443d10abed0fe9d2e3',1,'Font']]],
+  ['getunderlined',['getUnderlined',['../classFont.html#aed3932c16a226bcfea6fa43edc9f5c97',1,'Font']]],
   ['getwxfont',['getWxFont',['../classFont.html#a4ee204fe1ad6485a43c572146f741c92',1,'Font']]],
   ['getyad',['getYAD',['../qsastime_8c.html#a3b5af20594b02a640ef7f8422ad29b12',1,'getYAD(int *year, int *ifleapyear, int *doy, const MJDtime *MJD, int forceJulian):&#160;qsastime.c'],['../qsastimeP_8h.html#a5e4bad0354598a5b258808c41b2d8d59',1,'getYAD(int *year, int *ifleapyear, int *doy, const MJDtime *MJD, int forceJulian):&#160;qsastime.c']]],
   ['gfam',['gfam',['../classplstream.html#a61a18d3cdbcbfad10cb2ced205eae617',1,'plstream']]],
@@ -95,12 +96,12 @@ var searchData=
   ['grfill',['grfill',['../plcore_8c.html#a859a0f4ec99bc066171dda65bbd7172c',1,'grfill(short *x, short *y, PLINT npts):&#160;plcore.c'],['../plcore_8h.html#a77d9cf615432469a524b7bc2dd14aeef',1,'grfill(short *, short *, PLINT):&#160;plcore.h']]],
   ['grgradient',['grgradient',['../plcore_8c.html#a7498b6e873f50e540504be66a4e8dde0',1,'grgradient(short *x, short *y, PLINT npts):&#160;plcore.c'],['../plcore_8h.html#a56859b60f4eb1d9be698cfd7e1b02941',1,'grgradient(short *, short *, PLINT):&#160;plcore.h']]],
   ['grid_5fbox',['grid_box',['../plbox_8c.html#ae3bc5f7905a6f76d3fd131d609cd066a',1,'plbox.c']]],
-  ['grid_5fcsa',['GRID_CSA',['../classplplot.html#ac7e8d796ea6f9dd2556a6212cdf0dba7',1,'plplot::GRID_CSA()'],['../plplot_8h.html#a5fbcfaa3170cb529bf1635ff609a78fa',1,'GRID_CSA():&#160;plplot.h'],['../namespaceplplotc.html#a637c93aafb8a043eafe6e45e4c8fe7fe',1,'plplotc.GRID_CSA()'],['../namespaceplplotc__fixed.html#a48833f81bde3cf17d99b5774751d2e9a',1,'plplotc_fixed.GRID_CSA()']]],
-  ['grid_5fdtli',['GRID_DTLI',['../classplplot.html#a69350e251c909eb5d9dc20469b532bcb',1,'plplot::GRID_DTLI()'],['../plplot_8h.html#abeff949898412780654cf7cca55561b2',1,'GRID_DTLI():&#160;plplot.h'],['../namespaceplplotc.html#a9c46b3ae31f7775cc68888dfe0dd5009',1,'plplotc.GRID_DTLI()'],['../namespaceplplotc__fixed.html#a2ad8fb126c83458eaa7c86a361997b04',1,'plplotc_fixed.GRID_DTLI()']]],
-  ['grid_5fnnaidw',['GRID_NNAIDW',['../classplplot.html#a14854e59f92a3552380e29a55d06622f',1,'plplot::GRID_NNAIDW()'],['../plgridd_8c.html#ae4e0ce809ddd71b6c228526472fb9f6d',1,'grid_nnaidw(PLFLT_VECTOR x, PLFLT_VECTOR y, PLFLT_VECTOR z, int npts, PLFLT_VECTOR xg, int nptsx, PLFLT_VECTOR yg, int nptsy, PLF2OPS zops, PLPointer zgp):&#160;plgridd.c'],['../plplot_8h.html#ac863b08f442af857a166e36ad4721058',1,'GRID_NNAIDW():&#160;plplot.h'],['../namespaceplplotc.html#a41083538b2b79e26bb68ceb7f1bd7220',1,'plplotc.GRID_NNAIDW()'],['../namespaceplplotc__fixed.html#a5bb69d831536a32008ec1aff57d8af82',1,'plplotc_fixed.GRID_NNAIDW()']]],
-  ['grid_5fnni',['GRID_NNI',['../classplplot.html#aae7efb1735fa85ed208db2d57f2d0b48',1,'plplot::GRID_NNI()'],['../plplot_8h.html#a52d6e7517c3ffac5a0e8a71bdfbc261c',1,'GRID_NNI():&#160;plplot.h'],['../namespaceplplotc.html#a3017ccbfedf84973d1eb6c1def54bdc1',1,'plplotc.GRID_NNI()'],['../namespaceplplotc__fixed.html#a64b1a61da40a67250b6a4745bc86dc6a',1,'plplotc_fixed.GRID_NNI()']]],
-  ['grid_5fnnidw',['GRID_NNIDW',['../classplplot.html#a1acbbb4c8a1b2da431aafe9b0383a8d1',1,'plplot::GRID_NNIDW()'],['../plgridd_8c.html#ac16cb8893c332bd2ebf6f98cddbe1510',1,'grid_nnidw(PLFLT_VECTOR x, PLFLT_VECTOR y, PLFLT_VECTOR z, int npts, PLFLT_VECTOR xg, int nptsx, PLFLT_VECTOR yg, int nptsy, PLF2OPS zops, PLPointer zgp, int knn_order):&#160;plgridd.c'],['../plplot_8h.html#aea4b4b399c7eff90105f16be688f869d',1,'GRID_NNIDW():&#160;plplot.h'],['../namespaceplplotc.html#a9dadd7e9c8534b465792964bd952766c',1,'plplotc.GRID_NNIDW()'],['../namespaceplplotc__fixed.html#a2dd8f3c42f3dc1d4ab1fd0b61d5caceb',1,'plplotc_fixed.GRID_NNIDW()']]],
-  ['grid_5fnnli',['GRID_NNLI',['../classplplot.html#ae46f869cff5269e5ddac49fbf11f8ff5',1,'plplot::GRID_NNLI()'],['../plgridd_8c.html#a4f700a1dd26e440d0371d26e7cf12366',1,'grid_nnli(PLFLT_VECTOR x, PLFLT_VECTOR y, PLFLT_VECTOR z, int npts, PLFLT_VECTOR xg, int nptsx, PLFLT_VECTOR yg, int nptsy, PLF2OPS zops, PLPointer zgp, PLFLT threshold):&#160;plgridd.c'],['../plplot_8h.html#adb70a2b8a3cc84206d433e80e79162f2',1,'GRID_NNLI():&#160;plplot.h'],['../namespaceplplotc.html#aed82e9f2bf7583a3528d1eeb494423af',1,'plplotc.GRID_NNLI()'],['../namespaceplplotc__fixed.html#aab72e712e85678087a67ec91801a570c',1,'plplotc_fixed.GRID_NNLI()']]],
+  ['grid_5fcsa',['GRID_CSA',['../plplot_8h.html#a5fbcfaa3170cb529bf1635ff609a78fa',1,'GRID_CSA():&#160;plplot.h'],['../namespaceplplot.html#ac7e8d796ea6f9dd2556a6212cdf0dba7',1,'plplot::GRID_CSA()'],['../namespaceplplotc.html#a00dc056fe56ebe194647cbd1162e343c',1,'plplotc.GRID_CSA()']]],
+  ['grid_5fdtli',['GRID_DTLI',['../plplot_8h.html#abeff949898412780654cf7cca55561b2',1,'GRID_DTLI():&#160;plplot.h'],['../namespaceplplot.html#a69350e251c909eb5d9dc20469b532bcb',1,'plplot::GRID_DTLI()'],['../namespaceplplotc.html#ac14adf4dbaa8066db6c3ba43dcb3e2f8',1,'plplotc.GRID_DTLI()']]],
+  ['grid_5fnnaidw',['GRID_NNAIDW',['../plplot_8h.html#ac863b08f442af857a166e36ad4721058',1,'GRID_NNAIDW():&#160;plplot.h'],['../namespaceplplot.html#a14854e59f92a3552380e29a55d06622f',1,'plplot::GRID_NNAIDW()'],['../namespaceplplotc.html#ac3170cbecddcf4693801fffa3d313993',1,'plplotc.GRID_NNAIDW()'],['../plgridd_8c.html#ae4e0ce809ddd71b6c228526472fb9f6d',1,'grid_nnaidw():&#160;plgridd.c']]],
+  ['grid_5fnni',['GRID_NNI',['../plplot_8h.html#a52d6e7517c3ffac5a0e8a71bdfbc261c',1,'GRID_NNI():&#160;plplot.h'],['../namespaceplplot.html#aae7efb1735fa85ed208db2d57f2d0b48',1,'plplot::GRID_NNI()'],['../namespaceplplotc.html#a8ce11df5f81041361d9a7da90c273424',1,'plplotc.GRID_NNI()']]],
+  ['grid_5fnnidw',['GRID_NNIDW',['../plplot_8h.html#aea4b4b399c7eff90105f16be688f869d',1,'GRID_NNIDW():&#160;plplot.h'],['../namespaceplplot.html#a1acbbb4c8a1b2da431aafe9b0383a8d1',1,'plplot::GRID_NNIDW()'],['../namespaceplplotc.html#ad49fbf71d1599309e9d51e5f7abb0f85',1,'plplotc.GRID_NNIDW()'],['../plgridd_8c.html#ac16cb8893c332bd2ebf6f98cddbe1510',1,'grid_nnidw():&#160;plgridd.c']]],
+  ['grid_5fnnli',['GRID_NNLI',['../plplot_8h.html#adb70a2b8a3cc84206d433e80e79162f2',1,'GRID_NNLI():&#160;plplot.h'],['../namespaceplplot.html#ae46f869cff5269e5ddac49fbf11f8ff5',1,'plplot::GRID_NNLI()'],['../namespaceplplotc.html#ac3ae103afcb084bddb043b6ab48b552b',1,'plplotc.GRID_NNLI()'],['../plgridd_8c.html#a4f700a1dd26e440d0371d26e7cf12366',1,'grid_nnli():&#160;plgridd.c']]],
   ['griddata',['griddata',['../classplstream.html#a2463e096bfd2fe60b6dd319ef864ffe3',1,'plstream']]],
   ['grimage',['grimage',['../plimage_8c.html#a3bb953b941f306756707370648093b64',1,'grimage(short *x, short *y, unsigned short *z, PLINT nx, PLINT ny):&#160;plimage.c'],['../plplotP_8h.html#a3bb953b941f306756707370648093b64',1,'grimage(short *x, short *y, unsigned short *z, PLINT nx, PLINT ny):&#160;plimage.c']]],
   ['grline',['grline',['../plcore_8c.html#a05047fa1f14551c0664c4d5192eb4b1a',1,'grline(short *x, short *y, PLINT PL_UNUSED(npts)):&#160;plcore.c'],['../plcore_8h.html#a04aa64064f4f9a6a73a3f357c802f88f',1,'grline(short *, short *, PLINT):&#160;plcore.h']]],
