@@ -4,6 +4,7 @@ var searchData=
   ['setsub',['SETSUB',['../metadefs_8h.html#a5b0117b6132f309a8d5c393433acd3cc',1,'metadefs.h']]],
   ['sign',['SIGN',['../plplotP_8h.html#a8c4a9e5e4622948245de4ec0b5d38329',1,'plplotP.h']]],
   ['sizeof',['SIZEOF',['../cd_8h.html#ab4e7a10b0e2cf79aa0978d3bbe1e1268',1,'cd.h']]],
+  ['sizeof_5fdptr',['SIZEOF_DPTR',['../moc__predefs_8h.html#addad5b57ed33bc5c79361574d9e03c06',1,'moc_predefs.h']]],
   ['snprintf',['snprintf',['../plplotP_8h.html#aa367b75c5aed883fef5befbdf04835a4',1,'plplotP.h']]],
   ['snscanf',['snscanf',['../plplotP_8h.html#a690e5d3e324df4a0bcc627f25545943b',1,'plplotP.h']]],
   ['source_5fdir',['SOURCE_DIR',['../plplot__config_8h.html#a9343e0f8dda9d377d1b08b9f7d072d3f',1,'plplot_config.h']]],
@@ -76,12 +77,15 @@ var searchData=
   ['swig_5fisok',['SWIG_IsOK',['../plplotluacLUA__wrap_8c.html#aea8ef410fde907633cb76d9d18131fa1',1,'SWIG_IsOK():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#aea8ef410fde907633cb76d9d18131fa1',1,'SWIG_IsOK():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#aea8ef410fde907633cb76d9d18131fa1',1,'SWIG_IsOK():&#160;plplotcPYTHON_wrap.c']]],
   ['swig_5fisptrtype',['SWIG_isptrtype',['../plplotluacLUA__wrap_8c.html#ac24315f20782462ad057bf1c8309a616',1,'plplotluacLUA_wrap.c']]],
   ['swig_5fistmpobj',['SWIG_IsTmpObj',['../plplotluacLUA__wrap_8c.html#aa8f2563a536468b40dc33843d4bb7efe',1,'SWIG_IsTmpObj():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#aa8f2563a536468b40dc33843d4bb7efe',1,'SWIG_IsTmpObj():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#aa8f2563a536468b40dc33843d4bb7efe',1,'SWIG_IsTmpObj():&#160;plplotcPYTHON_wrap.c']]],
+  ['swig_5flua_5fadd_5fboolean',['SWIG_Lua_add_boolean',['../plplotluacLUA__wrap_8c.html#afd5580acc2cb0c0eeaf0644bac06f99e',1,'plplotluacLUA_wrap.c']]],
   ['swig_5flua_5fadd_5ffunction',['SWIG_Lua_add_function',['../plplotluacLUA__wrap_8c.html#a4e0088e1d53848f80738e5a49f1c0cf3',1,'plplotluacLUA_wrap.c']]],
   ['swig_5flua_5fbinary',['SWIG_LUA_BINARY',['../plplotluacLUA__wrap_8c.html#af2062cfc3a6907d38c2587cdab77ae38',1,'plplotluacLUA_wrap.c']]],
   ['swig_5flua_5fchar',['SWIG_LUA_CHAR',['../plplotluacLUA__wrap_8c.html#a50c58df5c9bd1cea902021a7f7fc9896',1,'plplotluacLUA_wrap.c']]],
+  ['swig_5flua_5fconsttab_5fbinary',['SWIG_LUA_CONSTTAB_BINARY',['../plplotluacLUA__wrap_8c.html#a38564dfb0235d7ba0f543836919b6dac',1,'plplotluacLUA_wrap.c']]],
   ['swig_5flua_5fconsttab_5fchar',['SWIG_LUA_CONSTTAB_CHAR',['../plplotluacLUA__wrap_8c.html#af21b898b6e053c8bb73855969e0888b0',1,'plplotluacLUA_wrap.c']]],
   ['swig_5flua_5fconsttab_5ffloat',['SWIG_LUA_CONSTTAB_FLOAT',['../plplotluacLUA__wrap_8c.html#a86474eb3525b32c80966dde2330e9596',1,'plplotluacLUA_wrap.c']]],
   ['swig_5flua_5fconsttab_5fint',['SWIG_LUA_CONSTTAB_INT',['../plplotluacLUA__wrap_8c.html#a81533fe9e3e23fc8a0caad2a15ddc953',1,'plplotluacLUA_wrap.c']]],
+  ['swig_5flua_5fconsttab_5fpointer',['SWIG_LUA_CONSTTAB_POINTER',['../plplotluacLUA__wrap_8c.html#ab5c3df1096e1d0596e6401e9aaf91f4b',1,'plplotluacLUA_wrap.c']]],
   ['swig_5flua_5fconsttab_5fstring',['SWIG_LUA_CONSTTAB_STRING',['../plplotluacLUA__wrap_8c.html#a9bcdad1f49921f12301ceb55b31f7f48',1,'plplotluacLUA_wrap.c']]],
   ['swig_5flua_5fflavor_5felua',['SWIG_LUA_FLAVOR_ELUA',['../plplotluacLUA__wrap_8c.html#a00a6f75261552001dd1ac741f712d82f',1,'plplotluacLUA_wrap.c']]],
   ['swig_5flua_5fflavor_5feluac',['SWIG_LUA_FLAVOR_ELUAC',['../plplotluacLUA__wrap_8c.html#a351d33087485b24840afe357df576385',1,'plplotluacLUA_wrap.c']]],
@@ -111,6 +115,7 @@ var searchData=
   ['swig_5fnewvarlink',['SWIG_newvarlink',['../plplotcPYTHON__wrap_8c.html#a840e0b11d64ac8d72e9f72d518cc67be',1,'plplotcPYTHON_wrap.c']]],
   ['swig_5fnullreferenceerror',['SWIG_NullReferenceError',['../plplot__octaveOCTAVE__wrap_8cxx.html#aa11fe417abd4c5a02d31cc1a51dee007',1,'SWIG_NullReferenceError():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#aa11fe417abd4c5a02d31cc1a51dee007',1,'SWIG_NullReferenceError():&#160;plplotcPYTHON_wrap.c']]],
   ['swig_5foctave_5fadderrormsg',['SWIG_Octave_AddErrorMsg',['../plplot__octaveOCTAVE__wrap_8cxx.html#a074b6a028433944b362f531ee7a7fa5f',1,'plplot_octaveOCTAVE_wrap.cxx']]],
+  ['swig_5foctave_5fbound_5ffunc',['SWIG_OCTAVE_BOUND_FUNC',['../plplot__octaveOCTAVE__wrap_8cxx.html#a57694a6e3a7e13e344fb5828a78fbb25',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['swig_5foctave_5fconvertptr',['SWIG_Octave_ConvertPtr',['../plplot__octaveOCTAVE__wrap_8cxx.html#a059ec983f00a9ff600d30f35b72b1737',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['swig_5foctave_5fprereq',['SWIG_OCTAVE_PREREQ',['../plplot__octaveOCTAVE__wrap_8cxx.html#a448761d7811a0a61bd974332adf5ea77',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['swig_5fok',['SWIG_OK',['../plplotluacLUA__wrap_8c.html#af9ecbac56d4c5cd6104ae8f6bb82e9f7',1,'SWIG_OK():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#af9ecbac56d4c5cd6104ae8f6bb82e9f7',1,'SWIG_OK():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#af9ecbac56d4c5cd6104ae8f6bb82e9f7',1,'SWIG_OK():&#160;plplotcPYTHON_wrap.c']]],
