@@ -5,8 +5,10 @@ var searchData=
   ['u_5flong',['U_LONG',['../pdf_8h.html#a4dce060e264ba01155a02c1f75540285',1,'pdf.h']]],
   ['u_5fshort',['U_SHORT',['../pdf_8h.html#a6d72945d8d77c9fd10f6d1d0bba7eb6a',1,'pdf.h']]],
   ['undef',['UNDEF',['../plshade_8c.html#abde25a67f4046530ae1c572cefeb5869',1,'plshade.c']]],
+  ['unix',['unix',['../moc__predefs_8h.html#a4e65214f450ef6326b96b52e6dd5714b',1,'moc_predefs.h']]],
   ['update_5fh_5fscrollbar',['UPDATE_H_SCROLLBAR',['../plframe_8c.html#a48873796dd91962eb99410db39704c29',1,'UPDATE_H_SCROLLBAR():&#160;plframe.c'],['../plplotter_8c.html#a48873796dd91962eb99410db39704c29',1,'UPDATE_H_SCROLLBAR():&#160;plplotter.c']]],
   ['update_5fv_5fscrollbar',['UPDATE_V_SCROLLBAR',['../plframe_8c.html#a657b634edd312e28641b0bd2be047f85',1,'UPDATE_V_SCROLLBAR():&#160;plframe.c'],['../plplotter_8c.html#a657b634edd312e28641b0bd2be047f85',1,'UPDATE_V_SCROLLBAR():&#160;plplotter.c']]],
   ['upper_5fmask',['UPPER_MASK',['../mt19937ar_8c.html#a39bc458849360f8f371b54c4365d397f',1,'mt19937ar.c']]],
-  ['use_5fqhull',['USE_QHULL',['../delaunay_8c.html#a71d612363a241c0f6fca4e05ad5ac0cb',1,'delaunay.c']]]
+  ['use_5fqhull',['USE_QHULL',['../delaunay_8c.html#a71d612363a241c0f6fca4e05ad5ac0cb',1,'delaunay.c']]],
+  ['usingdll',['USINGDLL',['../moc__predefs_8h.html#ada5d42c0cb267195668ae1fdef357778',1,'moc_predefs.h']]]
 ];
