@@ -31,6 +31,7 @@ var searchData=
   ['pl_5fcolorbar_5flabel_5fleft',['PL_COLORBAR_LABEL_LEFT',['../plplot_8h.html#ac81ae9a4c7016376c8904cbdc6f29aee',1,'plplot.h']]],
   ['pl_5fcolorbar_5flabel_5fright',['PL_COLORBAR_LABEL_RIGHT',['../plplot_8h.html#a83fb83c49b854017aeb18c2160911a92',1,'plplot.h']]],
   ['pl_5fcolorbar_5flabel_5ftop',['PL_COLORBAR_LABEL_TOP',['../plplot_8h.html#a38466c6fea905d6221e6a338f71d9b5b',1,'plplot.h']]],
+  ['pl_5fcolorbar_5fnull',['PL_COLORBAR_NULL',['../plplot_8h.html#a9fe9faa64e6e8176ab63b4976de3a8d0',1,'plplot.h']]],
   ['pl_5fcolorbar_5forient_5fbottom',['PL_COLORBAR_ORIENT_BOTTOM',['../plplot_8h.html#a3515daea0a292f5471fa2ad275990b09',1,'plplot.h']]],
   ['pl_5fcolorbar_5forient_5fleft',['PL_COLORBAR_ORIENT_LEFT',['../plplot_8h.html#ae9a9558d97dfdb6d9fd92fcc70e28678',1,'plplot.h']]],
   ['pl_5fcolorbar_5forient_5fright',['PL_COLORBAR_ORIENT_RIGHT',['../plplot_8h.html#ac6cb8a5f5563286a76b84f3c8ddeab34',1,'plplot.h']]],
@@ -39,6 +40,8 @@ var searchData=
   ['pl_5fcolorbar_5fshade_5flabel',['PL_COLORBAR_SHADE_LABEL',['../plplot_8h.html#a58a4cf16afb401d8c65f944770c53d49',1,'plplot.h']]],
   ['pl_5fdefault_5fcmap0_5ffile',['PL_DEFAULT_CMAP0_FILE',['../plplot__config_8h.html#afbf5142dfff94e591a7b4f22cd3c163f',1,'plplot_config.h']]],
   ['pl_5fdefault_5fcmap1_5ffile',['PL_DEFAULT_CMAP1_FILE',['../plplot__config_8h.html#ab035fe71ecb650b38509704a6084231c',1,'plplot_config.h']]],
+  ['pl_5fdefault_5fncol0',['PL_DEFAULT_NCOL0',['../plplot_8h.html#a5b22998d62215bec7f1dd37a7efe90e7',1,'plplot.h']]],
+  ['pl_5fdefault_5fncol1',['PL_DEFAULT_NCOL1',['../plplot_8h.html#a056c5638557c2ee1aefebfc5aa52b1ef',1,'plplot.h']]],
   ['pl_5fdouble',['PL_DOUBLE',['../plConfig_8h.html#a9713670c0bc31fbd2270fbf9d577949d',1,'plConfig.h']]],
   ['pl_5fdrawmode_5fdefault',['PL_DRAWMODE_DEFAULT',['../plplot_8h.html#ac5eeff3ef245c5b23310ba17946a284a',1,'plplot.h']]],
   ['pl_5fdrawmode_5freplace',['PL_DRAWMODE_REPLACE',['../plplot_8h.html#a4ae91e69b166f8e0b208bf5ddc1173f8',1,'plplot.h']]],
@@ -121,6 +124,7 @@ var searchData=
   ['pl_5flegend_5fcolor_5fbox',['PL_LEGEND_COLOR_BOX',['../plplot_8h.html#a55f9fd02e3c80518f175dbd9b2c135bb',1,'plplot.h']]],
   ['pl_5flegend_5fline',['PL_LEGEND_LINE',['../plplot_8h.html#a70f997ff03bb62308ec6e6b82783d6ee',1,'plplot.h']]],
   ['pl_5flegend_5fnone',['PL_LEGEND_NONE',['../plplot_8h.html#a39430311ce223e88826f0c92864eeba3',1,'plplot.h']]],
+  ['pl_5flegend_5fnull',['PL_LEGEND_NULL',['../plplot_8h.html#a887b4f171243fc277421b5d3139139ea',1,'plplot.h']]],
   ['pl_5flegend_5frow_5fmajor',['PL_LEGEND_ROW_MAJOR',['../plplot_8h.html#a67acdb622747723dd63d61c8db77ec3f',1,'plplot.h']]],
   ['pl_5flegend_5fsymbol',['PL_LEGEND_SYMBOL',['../plplot_8h.html#af9035c908614e1db71828eb2de742597',1,'plplot.h']]],
   ['pl_5flegend_5ftext_5fleft',['PL_LEGEND_TEXT_LEFT',['../plplot_8h.html#ae8e673b57f1894dce563b5e3680f04d9',1,'plplot.h']]],
@@ -169,6 +173,7 @@ var searchData=
   ['pl_5fposition_5fbottom',['PL_POSITION_BOTTOM',['../plplot_8h.html#a070f403a976e42378aad22e51d1a5285',1,'plplot.h']]],
   ['pl_5fposition_5finside',['PL_POSITION_INSIDE',['../plplot_8h.html#aac38c988f1ba35e2e861fe87368a17b5',1,'plplot.h']]],
   ['pl_5fposition_5fleft',['PL_POSITION_LEFT',['../plplot_8h.html#aea8b06633788da6fbc6988f63d6ab0e5',1,'plplot.h']]],
+  ['pl_5fposition_5fnull',['PL_POSITION_NULL',['../plplot_8h.html#aa41a26e4b01e0fb151fdc2ba2605cf9c',1,'plplot.h']]],
   ['pl_5fposition_5foutside',['PL_POSITION_OUTSIDE',['../plplot_8h.html#a51a7b6a259eb2137fa1d3f63f2bc3513',1,'plplot.h']]],
   ['pl_5fposition_5fright',['PL_POSITION_RIGHT',['../plplot_8h.html#abbe12ba62ad2169d23202cbcd6514f02',1,'plplot.h']]],
   ['pl_5fposition_5fsubpage',['PL_POSITION_SUBPAGE',['../plplot_8h.html#a3f53fc4e08007a1ca37b22c9f659a500',1,'plplot.h']]],
@@ -207,7 +212,6 @@ var searchData=
   ['plctime',['plctime',['../plplot_8h.html#a62b48f8c8943b09d19f6bbc75ceff1e6',1,'plplot.h']]],
   ['pld_5fbmpqt',['PLD_bmpqt',['../plDevs_8h.html#ad68cc9baaea52dc8947695df16a5cd45',1,'plDevs.h']]],
   ['pld_5fepscairo',['PLD_epscairo',['../plDevs_8h.html#a438a0783c60b30d0b8b5cac08d3e0bb2',1,'plDevs.h']]],
-  ['pld_5fepsqt',['PLD_epsqt',['../plDevs_8h.html#ae1f7e10ccb83b15fd6dbbb54f91a751b',1,'plDevs.h']]],
   ['pld_5fextcairo',['PLD_extcairo',['../plDevs_8h.html#a0293d58f6385e6220eb731564391f718',1,'plDevs.h']]],
   ['pld_5fextqt',['PLD_extqt',['../plDevs_8h.html#a60493b354dd7651bafe23208937aed6c',1,'plDevs.h']]],
   ['pld_5fjpgqt',['PLD_jpgqt',['../plDevs_8h.html#a8346a6839e0f3eb400778f86bc6d0e6a',1,'plDevs.h']]],
@@ -223,8 +227,10 @@ var searchData=
   ['pld_5fpngqt',['PLD_pngqt',['../plDevs_8h.html#a5eeb7c3e7207c2a446aa6dec78fdd878',1,'plDevs.h']]],
   ['pld_5fppmqt',['PLD_ppmqt',['../plDevs_8h.html#af687e8b8da0d8405796aaaaadac40189',1,'plDevs.h']]],
   ['pld_5fps',['PLD_ps',['../plDevs_8h.html#a4696047dc34c94b449c94cfb57251b84',1,'plDevs.h']]],
+  ['pld_5fpsc',['PLD_psc',['../plDevs_8h.html#a84cab3750b1385e172346425eb3ab185',1,'plDevs.h']]],
   ['pld_5fpscairo',['PLD_pscairo',['../plDevs_8h.html#ae8c59bcfdfec6ecaae58e43eb3dbd5ae',1,'plDevs.h']]],
   ['pld_5fpsttf',['PLD_psttf',['../plDevs_8h.html#a47a3f3906dc4ce4382c8bb30b397d4db',1,'plDevs.h']]],
+  ['pld_5fpsttfc',['PLD_psttfc',['../plDevs_8h.html#ab8bcf52744e47f14a936c995e378473f',1,'plDevs.h']]],
   ['pld_5fqtwidget',['PLD_qtwidget',['../plDevs_8h.html#adf31ffa1b2c2aafd65217caf31f84b69',1,'plDevs.h']]],
   ['pld_5fsvg',['PLD_svg',['../plDevs_8h.html#aff516eaaa04ea1d86619429cebab1f22',1,'plDevs.h']]],
   ['pld_5fsvgcairo',['PLD_svgcairo',['../plDevs_8h.html#a9398cd0089cd162a8607f22de8448871',1,'plDevs.h']]],
@@ -317,6 +323,7 @@ var searchData=
   ['plfill',['plfill',['../plplot_8h.html#a10221007d2c08a7117a70abab63dca51',1,'plplot.h']]],
   ['plfill3',['plfill3',['../plplot_8h.html#ad51faec84e8ab250bfdd2cdbea9bd331',1,'plplot.h']]],
   ['plflt2coord',['PLFLT2COORD',['../plmetafile_8c.html#a40efca8265e3ee8f3c8d0dde8cbd3e31',1,'plmetafile.c']]],
+  ['plflt_5fhuge_5fval',['PLFLT_HUGE_VAL',['../plplot_8h.html#a3ae76aa640bd420a6f9ca3128f6b6fca',1,'plplot.h']]],
   ['plflt_5fmax',['PLFLT_MAX',['../plplot_8h.html#a83342f0fa1e35b8979af38fb349ae5ed',1,'plplot.h']]],
   ['plflt_5fmin',['PLFLT_MIN',['../plplot_8h.html#a3d84581230aacab980c3b57c09ec0ab9',1,'plplot.h']]],
   ['plflush',['plflush',['../plplot_8h.html#ae58d2db18a9da35dc75fa895fd9c6fcc',1,'plplot.h']]],
@@ -530,6 +537,7 @@ var searchData=
   ['plplot_5fdefault_5fwidth_5fpixels',['PLPLOT_DEFAULT_WIDTH_PIXELS',['../plplotP_8h.html#a91cb3228499847af3a270c7b6ad19eb7',1,'plplotP.h']]],
   ['plplot_5fdefault_5fwidth_5fpoints',['PLPLOT_DEFAULT_WIDTH_POINTS',['../plplotP_8h.html#a7fcdda9368b70cb7ca54f5a74efe16c5',1,'plplotP.h']]],
   ['plplot_5fextended_5fsearch',['PLPLOT_EXTENDED_SEARCH',['../tclAPI_8c.html#afc8996c89333709dccb6e53ddf203c69',1,'tclAPI.c']]],
+  ['plplot_5fhave_5fconfig_5fh',['PLPLOT_HAVE_CONFIG_H',['../moc__predefs_8h.html#a7fa978f9fa246cfe72f980726dd18f6c',1,'moc_predefs.h']]],
   ['plplot_5fheight_5fa4_5fmm',['PLPLOT_HEIGHT_A4_MM',['../plplotP_8h.html#a90709d034193dd5dfdbdedcc8d393b54',1,'plplotP.h']]],
   ['plplot_5fheight_5fa5_5fmm',['PLPLOT_HEIGHT_A5_MM',['../plplotP_8h.html#a52ca90477cd17bcfc5315377db003d83',1,'plplotP.h']]],
   ['plplot_5fhome_5fenv',['PLPLOT_HOME_ENV',['../plplotP_8h.html#aa75c95ff00e85a94e00607777d07cae9',1,'plplotP.h']]],
@@ -542,6 +550,7 @@ var searchData=
   ['plplot_5fmutex_5frecursive',['PLPLOT_MUTEX_RECURSIVE',['../plplot__config_8h.html#a1656194b16a39df9359ce8ec4ebb851e',1,'plplot_config.h']]],
   ['plplot_5fpoints_5fper_5finch',['PLPLOT_POINTS_PER_INCH',['../plplotP_8h.html#a49a32722e9dcc0e01c3b3faee3ed082e',1,'plplotP.h']]],
   ['plplot_5ftcl_5fenv',['PLPLOT_TCL_ENV',['../plplotP_8h.html#a7ec795052c6fe6de491ff626aae9a09b',1,'plplotP.h']]],
+  ['plplot_5fuse_5fqt5',['PLPLOT_USE_QT5',['../plplot__config_8h.html#aa74725dd8b2c31bdf0e4f048a929e364',1,'plplot_config.h']]],
   ['plplot_5fversion',['PLPLOT_VERSION',['../plConfig_8h.html#ae0e22c058c258b6acce53c1dfa3aa2f7',1,'plConfig.h']]],
   ['plplot_5fversion_5fmajor',['PLPLOT_VERSION_MAJOR',['../plConfig_8h.html#a112cee99246ffbc75b38333bbe4de54b',1,'plConfig.h']]],
   ['plplot_5fversion_5fminor',['PLPLOT_VERSION_MINOR',['../plConfig_8h.html#ab93f2d5cd7570915e309faa0859986d5',1,'plConfig.h']]],
@@ -596,7 +605,6 @@ var searchData=
   ['plsfnam',['plsfnam',['../plplot_8h.html#ae180cc25da7b407dc72577b730b9b9ed',1,'plplot.h']]],
   ['plsfont',['plsfont',['../plplot_8h.html#ad66be92ad40c6e8cdc4de36d6868020f',1,'plplot.h']]],
   ['plshade',['plshade',['../plplot_8h.html#aa864df027d27c705b65e2b1e2170ba0c',1,'plplot.h']]],
-  ['plshade1',['plshade1',['../plplot_8h.html#ac3094aae373d21ad461b961593e9482a',1,'plplot.h']]],
   ['plshades',['plshades',['../plplot_8h.html#a939743b6e786099fc3b9e50e5a720c62',1,'plplot.h']]],
   ['plslabelfunc',['plslabelfunc',['../plplot_8h.html#a9374ca78cec47194d25c5b28533ef688',1,'plplot.h']]],
   ['plsmaj',['plsmaj',['../plplot_8h.html#a0a5e4fdc768d2d28d39a283905f84141',1,'plplot.h']]],
@@ -618,6 +626,7 @@ var searchData=
   ['plstate_5fcmap1',['PLSTATE_CMAP1',['../plplotP_8h.html#ad0a2af1aef551a9ccd4ca00c7fbbd834',1,'plplotP.h']]],
   ['plstate_5fcolor0',['PLSTATE_COLOR0',['../plplotP_8h.html#aea93ee07e6a29ea6fdee6f1362104618',1,'plplotP.h']]],
   ['plstate_5fcolor1',['PLSTATE_COLOR1',['../plplotP_8h.html#aa4d5d7ee225e17548f4066fc4bd27d4e',1,'plplotP.h']]],
+  ['plstate_5feofill',['PLSTATE_EOFILL',['../plplotP_8h.html#a3dde0c70bec44bd3a4861e427058df0f',1,'plplotP.h']]],
   ['plstate_5ffill',['PLSTATE_FILL',['../plplotP_8h.html#a32be3518883413bd04abf4243ee7abda',1,'plplotP.h']]],
   ['plstate_5fsym',['PLSTATE_SYM',['../plplotP_8h.html#a6b3c4f17d069eafddc5971d9988fe5e4',1,'plplotP.h']]],
   ['plstate_5fwidth',['PLSTATE_WIDTH',['../plplotP_8h.html#a6d50332cd83f8d864604ff541655b2be',1,'plplotP.h']]],
@@ -661,8 +670,10 @@ var searchData=
   ['polyline',['POLYLINE',['../metadefs_8h.html#ae38b6e405395fa5184aaccb260ccb135',1,'metadefs.h']]],
   ['pos',['POS',['../plshade_8c.html#a63cb3834e6075ddad87f8ce324e53988',1,'plshade.c']]],
   ['positive_5fslope',['POSITIVE_SLOPE',['../plshade_8c.html#a370d47b188a024bae0cbdc4fb2708ba8',1,'plshade.c']]],
+  ['proc_5fstr_5fstring_5flength',['PROC_STR_STRING_LENGTH',['../ps_8c.html#ac98d0c577b29b1167234aa4832c4ece0',1,'PROC_STR_STRING_LENGTH():&#160;ps.c'],['../psttf_8cc.html#ac98d0c577b29b1167234aa4832c4ece0',1,'PROC_STR_STRING_LENGTH():&#160;psttf.cc']]],
   ['psx',['PSX',['../ps_8h.html#a81bd405f224a24cc3fd0db79f40507c5',1,'ps.h']]],
   ['psy',['PSY',['../ps_8h.html#a1a0aebfec9c29e451f68a9cca220252f',1,'ps.h']]],
+  ['py_5fhash_5ft',['Py_hash_t',['../plplotcPYTHON__wrap_8c.html#a361689e69dc1560a9e9ee88193814ddd',1,'plplotcPYTHON_wrap.c']]],
   ['py_5fnotimplemented',['Py_NotImplemented',['../plplotcPYTHON__wrap_8c.html#ae5603e8c5fd8ec50c4936e1012a58cb4',1,'plplotcPYTHON_wrap.c']]],
   ['py_5fssize_5ft_5fmax',['PY_SSIZE_T_MAX',['../plplotcPYTHON__wrap_8c.html#aa5b5990f814eb53730c24c7f911f9132',1,'plplotcPYTHON_wrap.c']]],
   ['py_5fssize_5ft_5fmin',['PY_SSIZE_T_MIN',['../plplotcPYTHON__wrap_8c.html#a9fbcf3e88f34de99fb3bd045cffd6ce4',1,'plplotcPYTHON_wrap.c']]],
@@ -672,7 +683,7 @@ var searchData=
   ['pydescr_5ftype',['PyDescr_TYPE',['../plplotcPYTHON__wrap_8c.html#a0d2bc679367576eb4071b8c3bfe13edc',1,'plplotcPYTHON_wrap.c']]],
   ['pyexc_5fstopiteration',['PyExc_StopIteration',['../plplotcPYTHON__wrap_8c.html#a0cba46b26eb93c57b8b96696ba92adb4',1,'plplotcPYTHON_wrap.c']]],
   ['pyint_5ffromsize_5ft',['PyInt_FromSize_t',['../plplotcPYTHON__wrap_8c.html#a2a72c6061f4d23c35a8340448dd0cd2b',1,'plplotcPYTHON_wrap.c']]],
-  ['pyobject_5fdel',['PyObject_Del',['../plplotcPYTHON__wrap_8c.html#a5777895532ba038acdbde39ef6f78a82',1,'PyObject_Del():&#160;plplotcPYTHON_wrap.c'],['../plplotcPYTHON__wrap_8c.html#a3e72f1bb4b2af8f115a750f832d421b4',1,'PyObject_DEL():&#160;plplotcPYTHON_wrap.c']]],
+  ['pyobject_5fdel',['PyObject_DEL',['../plplotcPYTHON__wrap_8c.html#a3e72f1bb4b2af8f115a750f832d421b4',1,'plplotcPYTHON_wrap.c']]],
   ['pyobject_5fgenericgetattr',['PyObject_GenericGetAttr',['../plplotcPYTHON__wrap_8c.html#a2d659e3ecdc8d792ec516753e6fd37a2',1,'plplotcPYTHON_wrap.c']]],
   ['pyos_5fsnprintf',['PyOS_snprintf',['../plplotcPYTHON__wrap_8c.html#aaf424b640ab3bb23906652e73030992b',1,'plplotcPYTHON_wrap.c']]],
   ['pysequence_5ffast_5fget_5fitem',['PySequence_Fast_GET_ITEM',['../plplotcPYTHON__wrap_8c.html#ada824e75a50f73e7439516caeaecb478',1,'plplotcPYTHON_wrap.c']]],
