@@ -63,7 +63,6 @@ var searchData=
   ['c_5fplgyax',['c_plgyax',['../plcore_8c.html#ae147ba26e63df579fc9434c6c4cbc3cd',1,'c_plgyax():&#160;plcore.c'],['../namespaceplplot.html#a814bbaa498ccc04e9cf97a7cac4d86ef',1,'plplot::c_plgyax()'],['../plplot_8h.html#a949c1a3b75363b541294ebed21b0e26c',1,'c_plgyax():&#160;plplot.h']]],
   ['c_5fplgzax',['c_plgzax',['../plcore_8c.html#a720bd62d527c1db65f35b344c03140e9',1,'c_plgzax():&#160;plcore.c'],['../namespaceplplot.html#a0d09d91220c22c8d90eb8a4c94a2117f',1,'plplot::c_plgzax()'],['../plplot_8h.html#ab8b6270a88d9d8b737bf2dfac895cc04',1,'c_plgzax():&#160;plplot.h']]],
   ['c_5fplhist',['c_plhist',['../plhist_8c.html#a68d232788ff549df5301a47a5568eb82',1,'c_plhist():&#160;plhist.c'],['../namespaceplplot.html#aed4d8d7bc69de498a92b4c8f305e1ecc',1,'plplot::c_plhist()'],['../plplot_8h.html#a7b89fa38b97399d9dcd2758a47bcf906',1,'c_plhist():&#160;plhist.c']]],
-  ['c_5fplhls',['c_plhls',['../namespaceplplot.html#ae64e0e1a256915d94bf330a6427cedce',1,'plplot']]],
   ['c_5fplhlsrgb',['c_plhlsrgb',['../plctrl_8c.html#afe5c216f6c83e64df5a16b48b2f7af15',1,'c_plhlsrgb():&#160;plctrl.c'],['../namespaceplplot.html#a9da5d6fa041c7256061955d7ace6e62a',1,'plplot::c_plhlsrgb()'],['../plplot_8h.html#a9e9560a0fddc381de37802b7d14ec1e1',1,'c_plhlsrgb():&#160;plplot.h']]],
   ['c_5fplimage',['c_plimage',['../plimage_8c.html#ae0d2aee9a1e865cda3428d51990ed46f',1,'c_plimage():&#160;plimage.c'],['../namespaceplplot.html#a6ca701d920c0c0708ad8685969baab6e',1,'plplot::c_plimage()'],['../plplot_8h.html#a8e4c28058e6347f092502d71de4537de',1,'c_plimage():&#160;plimage.c']]],
   ['c_5fplimagefr',['c_plimagefr',['../plimage_8c.html#a870571ff0cc72aa355cc64c68b94a316',1,'c_plimagefr():&#160;plimage.c'],['../namespaceplplot.html#a4b288976d5756013c9c41dcee6b48bc7',1,'plplot::c_plimagefr()'],['../plplot_8h.html#a7f5ce2feda00354aebbd4073db12c492',1,'c_plimagefr():&#160;plimage.c']]],
@@ -101,8 +100,6 @@ var searchData=
   ['c_5fplptex3',['c_plptex3',['../plsym_8c.html#a9c632c8be5cce4a0668faeede29f80aa',1,'c_plptex3():&#160;plsym.c'],['../namespaceplplot.html#aaee7e14d276eecfd916f55a794bf3a69',1,'plplot::c_plptex3()'],['../plplot_8h.html#a308b222be7f960448b9e3b59378e746c',1,'c_plptex3():&#160;plsym.c']]],
   ['c_5fplrandd',['c_plrandd',['../plctrl_8c.html#ac9d5de2ad9d25373fa2b91b1929937c8',1,'c_plrandd():&#160;plctrl.c'],['../namespaceplplot.html#ab4820fff80380f7c289317fcf2ed5ca7',1,'plplot::c_plrandd()'],['../plplot_8h.html#acf3655ca771545e49a3d28edcef394f0',1,'c_plrandd():&#160;plctrl.c']]],
   ['c_5fplreplot',['c_plreplot',['../plcore_8c.html#a521895943ac77a578e66673a7a26ad2a',1,'c_plreplot():&#160;plcore.c'],['../namespaceplplot.html#a07d9711dc10fbf9ea7fdffb1e9d91147',1,'plplot::c_plreplot()'],['../plplot_8h.html#a54683e3343102a1ea4cf61fcaef13a8f',1,'c_plreplot():&#160;plcore.c']]],
-  ['c_5fplrgb',['c_plrgb',['../namespaceplplot.html#a767be979249448d1eab2543023889bbe',1,'plplot']]],
-  ['c_5fplrgb1',['c_plrgb1',['../namespaceplplot.html#a738cf078078f3ca046d0f182ccb525df',1,'plplot']]],
   ['c_5fplrgbhls',['c_plrgbhls',['../plctrl_8c.html#a6c8ed7619abf08454dbb22ecb0130bb6',1,'c_plrgbhls():&#160;plctrl.c'],['../namespaceplplot.html#aa58560f9b13e65f1af751a4d475ceff6',1,'plplot::c_plrgbhls()'],['../plplot_8h.html#abb841ff8f757fca685d092cc64e2a200',1,'c_plrgbhls():&#160;plplot.h']]],
   ['c_5fplschr',['c_plschr',['../plsdef_8c.html#af1acef78b96c99f41520e46df15b7676',1,'c_plschr():&#160;plsdef.c'],['../namespaceplplot.html#a19594fe2d3a02328e079d1d129345d9c',1,'plplot::c_plschr()'],['../plplot_8h.html#a906b2f2e72c885b9783bbc6342b7c4da',1,'c_plschr():&#160;plsdef.c']]],
   ['c_5fplscmap0',['c_plscmap0',['../plctrl_8c.html#a7afa161e5608778fa50d10a462f09f11',1,'c_plscmap0():&#160;plctrl.c'],['../namespaceplplot.html#ae07e5a19342e485fb7f53ce444f87573',1,'plplot::c_plscmap0()'],['../plplot_8h.html#a04391c14259555227350b0262399243a',1,'c_plscmap0():&#160;plctrl.c']]],
@@ -135,7 +132,6 @@ var searchData=
   ['c_5fplsfnam',['c_plsfnam',['../plcore_8c.html#ae483472b1b57f3281c85c6e968b607d4',1,'c_plsfnam():&#160;plcore.c'],['../namespaceplplot.html#abf9a388c1ceb8a0d0c3c5c4e1038dcdf',1,'plplot::c_plsfnam()'],['../plplot_8h.html#a5337f550e9667396f3ebf85dd8508e65',1,'c_plsfnam():&#160;plcore.c']]],
   ['c_5fplsfont',['c_plsfont',['../plsym_8c.html#a6bcba7ea478412dd64c6f8e2eb834f06',1,'c_plsfont():&#160;plsym.c'],['../namespaceplplot.html#a5b068eafc7f0e005e57efdf2345bdd75',1,'plplot::c_plsfont()'],['../plplot_8h.html#a6393d02708ce42194302ccf3b94edf47',1,'c_plsfont():&#160;plsym.c']]],
   ['c_5fplshade',['c_plshade',['../plshade_8c.html#abc5a40007856cb961f2c192c799e8ace',1,'c_plshade():&#160;plshade.c'],['../namespaceplplot.html#aff655c6b4bfe486a4826d684f7eb8162',1,'plplot::c_plshade()'],['../plplot_8h.html#a7b704b2af4c8e38945eaa60cf37b529b',1,'c_plshade():&#160;plshade.c']]],
-  ['c_5fplshade1',['c_plshade1',['../plshade_8c.html#add9e26b8c903ec27b358b65b02957c09',1,'c_plshade1(PLFLT_VECTOR a, PLINT nx, PLINT ny, PLDEFINED_callback defined, PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax, PLFLT shade_min, PLFLT shade_max, PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width, PLINT min_color, PLFLT min_width, PLINT max_color, PLFLT max_width, PLFILL_callback fill, PLINT rectangular, PLTRANSFORM_callback pltr, PLPointer pltr_data):&#160;plshade.c'],['../plplot_8h.html#aecc19194ce082d26d401069d401fae1c',1,'c_plshade1(PLFLT_FE_POINTER a, PLINT nx, PLINT ny, PLDEFINED_callback defined, PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax, PLFLT shade_min, PLFLT shade_max, PLINT sh_cmap, PLFLT sh_color, PLFLT sh_width, PLINT min_color, PLFLT min_width, PLINT max_color, PLFLT max_width, PLFILL_callback fill, PLBOOL rectangular, PLTRANSFORM_callback pltr, PLPointer pltr_data):&#160;plshade.c']]],
   ['c_5fplshades',['c_plshades',['../plshade_8c.html#aa2ce196b86af4014f0f684381db7ad87',1,'c_plshades():&#160;plshade.c'],['../namespaceplplot.html#a965abbc050863a7fb8be7f8b9c95ba8c',1,'plplot::c_plshades()'],['../plplot_8h.html#ae6230a52f672b926669e78f76bc6154f',1,'c_plshades():&#160;plshade.c']]],
   ['c_5fplslabelfunc',['c_plslabelfunc',['../plbox_8c.html#a556211357054b5b8e994502b2d8d25f2',1,'c_plslabelfunc():&#160;plbox.c'],['../namespaceplplot.html#a3afe1f3514bd9954f8298df421bff580',1,'plplot::c_plslabelfunc()'],['../plplot_8h.html#ae52bcc90ec1061aecf3654dee05e56e0',1,'c_plslabelfunc():&#160;plbox.c']]],
   ['c_5fplsmaj',['c_plsmaj',['../plsdef_8c.html#aff3d7a3414c7ccf801748e9c594a8425',1,'c_plsmaj():&#160;plsdef.c'],['../namespaceplplot.html#aece3d659a68624da7636e7fa347c340e',1,'plplot::c_plsmaj()'],['../plplot_8h.html#a1c011f9eeab7ca11a5de4f2afdc2b501',1,'c_plsmaj():&#160;plsdef.c']]],
@@ -178,6 +174,7 @@ var searchData=
   ['c_5fplwidth',['c_plwidth',['../plcore_8c.html#a7e8aa99d537c6041b805f360f5c2b81c',1,'c_plwidth():&#160;plcore.c'],['../namespaceplplot.html#ac139793483186b792df01ce773ffe2be',1,'plplot::c_plwidth()'],['../plplot_8h.html#a35b056d50ccc18dab5832a99268e04ef',1,'c_plwidth():&#160;plcore.c']]],
   ['c_5fplwind',['c_plwind',['../plwind_8c.html#a29212e20abf13036271f1024db71fcd0',1,'c_plwind():&#160;plwind.c'],['../namespaceplplot.html#ab9aa6fab9ceb4a738f32415851035a7d',1,'plplot::c_plwind()'],['../plplot_8h.html#a02525a7edb3a826dc05004ed517263b9',1,'c_plwind():&#160;plwind.c']]],
   ['c_5fplxormod',['c_plxormod',['../plctrl_8c.html#a0d37f61f0fc93cdf16d4afffa2c4b28d',1,'c_plxormod():&#160;plctrl.c'],['../namespaceplplot.html#a4b47230cae3dd41861550e900b35b8c6',1,'plplot::c_plxormod()'],['../plplot_8h.html#a253a53d4c29ddbc1060d36b0ebc55a0e',1,'c_plxormod():&#160;plplot.h']]],
+  ['c_5fto_5fcharacter_5farray',['c_to_character_array',['../namespaceplplot__private__utilities.html#add53eaa77165db468f24d7ccb9509913',1,'plplot_private_utilities']]],
   ['cairo_5ffamily_5fcheck',['cairo_family_check',['../cairo_8c.html#af34b94fb2d1775703e4b35093f0e34f3',1,'cairo.c']]],
   ['calc_5fdidev',['calc_didev',['../plcore_8c.html#a26b8467bc1909781bdc9d74960d6d238',1,'calc_didev(void):&#160;plcore.c'],['../plcore_8h.html#a26b8467bc1909781bdc9d74960d6d238',1,'calc_didev(void):&#160;plcore.h']]],
   ['calc_5fdimap',['calc_dimap',['../plcore_8c.html#a0e92f358a43acd5c2fe68e40433a7b9c',1,'calc_dimap():&#160;plcore.c'],['../plcore_8h.html#ae79b9781138a1e5eaab96fc96015fbdb',1,'calc_dimap(void):&#160;plcore.h']]],
@@ -185,7 +182,7 @@ var searchData=
   ['calc_5fdiplt',['calc_diplt',['../plcore_8c.html#aaa88349701dbf79cbe3459271e11913d',1,'calc_diplt(void):&#160;plcore.c'],['../plcore_8h.html#aaa88349701dbf79cbe3459271e11913d',1,'calc_diplt(void):&#160;plcore.h']]],
   ['calc_5fworld',['calc_world',['../classplstream.html#ad96c824f1136684bae32c89d1d49e67c',1,'plstream']]],
   ['calculate_5flimits',['calculate_limits',['../pllegend_8c.html#aaeb3cac4f2e493e3bd6f35d8ea8d1252',1,'pllegend.c']]],
-  ['cast',['cast',['../classoctave__swig__type.html#adcaf50509093eef1e88a1f54d27feef9',1,'octave_swig_type']]],
+  ['cast',['cast',['../classoctave__swig__type.html#ae5ca39cd664c4bb9a367963fdbec089a',1,'octave_swig_type']]],
   ['catch_5fsegv',['catch_segv',['../test-drv-info_8c.html#af22f5388e7ee43a03372108a354ea57f',1,'catch_segv(int sig):&#160;test-drv-info.c'],['../test-drv-info_8c.html#ad0e945613ff49177b9c683f33a5e98e8',1,'catch_segv(int PL_UNUSED(sig)):&#160;test-drv-info.c']]],
   ['cdaddelem',['cdAddElem',['../cd_8c.html#a69ad2b5c2a19c23537506d551bb9e65c',1,'cd.c']]],
   ['cdappbyte',['cdAppByte',['../cd_8c.html#adbac702642a32ac50cd549eb58efb98e',1,'cd.c']]],
@@ -257,7 +254,7 @@ var searchData=
   ['cdsettextorient',['cdSetTextOrient',['../cd_8c.html#a7cb4e7c36f57bbba3052092ed45084fc',1,'cdSetTextOrient(cdImagePtr im, int xup, int yup, int xbase, int ybase):&#160;cd.c'],['../cd_8h.html#abf12721ea082a5c19868dd56a5fa17c7',1,'cdSetTextOrient(cdImagePtr im, int xup, int yup, int xbase, int ybase):&#160;cd.c']]],
   ['cdsettextpath',['cdSetTextPath',['../cd_8c.html#af49d1a8a01745dad78cb2ce5537fd464',1,'cdSetTextPath(cdImagePtr im, int tpath):&#160;cd.c'],['../cd_8h.html#a49c986cb79f6c1eebd5a9381a3cbdccc',1,'cdSetTextPath(cdImagePtr im, int tpath):&#160;cd.c']]],
   ['cdtext',['cdText',['../cd_8c.html#ad33e1a06f1d7c60a8e48e3dd076ff561',1,'cdText(cdImagePtr im, int x, int y, const char *ts):&#160;cd.c'],['../cd_8h.html#a4475722f5324f63392a5ee1d47dd581a',1,'cdText(cdImagePtr im, int x, int y, const char *):&#160;cd.c']]],
-  ['character_5farray_5fto_5fc',['character_array_to_c',['../classplplot__private__utilities.html#a5835c44719fafae24e87de4327ab7013',1,'plplot_private_utilities']]],
+  ['character_5farray_5fto_5fc',['character_array_to_c',['../namespaceplplot__private__utilities.html#a5835c44719fafae24e87de4327ab7013',1,'plplot_private_utilities']]],
   ['check_5fbuffer_5fsize',['check_buffer_size',['../plbuf_8c.html#a9af620a524d127e66e68dedf7f6bd89d',1,'check_buffer_size(PLStream *pls, size_t data_size):&#160;plbuf.c'],['../plmetafile_8c.html#affcee234ee73cf321c0099e83ffd8400',1,'check_buffer_size(PLmDev *dev, size_t need_size):&#160;plmetafile.c']]],
   ['check_5ffont_5fenvironment_5fvariables',['check_font_environment_variables',['../aqt_8c.html#a8b83e0b11669d22d5c6ef10ae876a6c5',1,'aqt.c']]],
   ['circle_5fbuild',['circle_build',['../delaunay_8c.html#a189383813491d98b6b00fe6299e15b91',1,'circle_build(circle *c, point *p0, point *p1, point *p2):&#160;nncommon.c'],['../nncommon_8c.html#a6778debede743a0e5e5dc210c456ab51',1,'circle_build(circle *c, point *p1, point *p2, point *p3):&#160;nncommon.c'],['../nnpi_8c.html#a189383813491d98b6b00fe6299e15b91',1,'circle_build(circle *c, point *p0, point *p1, point *p2):&#160;nncommon.c']]],
@@ -274,19 +271,19 @@ var searchData=
   ['clearbackground',['ClearBackground',['../classPlDevice.html#a691496af2bdad6325865ebf55a65ec8a',1,'PlDevice::ClearBackground()'],['../classwxPLDevice.html#adf773b89cce422a8993cff532d1468b5',1,'wxPLDevice::ClearBackground()']]],
   ['clearopts',['ClearOpts',['../classplstream.html#a3921c12c03ad654e354bbba07a6c57eb',1,'plstream']]],
   ['clipper',['Clipper',['../classClipper.html#ae06cce8f4ccf1e317fb17da05fbaf035',1,'Clipper::Clipper(wxDC *dc, const wxRect &amp;rect)'],['../classClipper.html#a90ecf4f2c049e2ce3564fa0f23aa16c5',1,'Clipper::Clipper(const Clipper &amp;)']]],
-  ['clone',['clone',['../classoctave__swig__type.html#ad49d4dcfce03cefde4fc95dff0bdd4dc',1,'octave_swig_type::clone()'],['../classoctave__swig__ref.html#a5830d08e161e9e6f374d6b73125e71fa',1,'octave_swig_ref::clone()'],['../classoctave__swig__packed.html#a96b1f76cb6f38dd50a5b3b0f5f4364e1',1,'octave_swig_packed::clone()']]],
+  ['clone',['clone',['../classoctave__swig__type.html#a0ff2343cfb9f5f07233661e0d6f619be',1,'octave_swig_type::clone()'],['../classoctave__swig__ref.html#a8b008bbef6f3dbcaef93a2653381f9cf',1,'octave_swig_ref::clone()'],['../classoctave__swig__packed.html#a11ad5111d10f8cee869d91bdd30ee534',1,'octave_swig_packed::clone()']]],
   ['close',['close',['../classPLMemoryMap.html#aa8bc2526af7e04aa2d31406ebf1aaedb',1,'PLMemoryMap']]],
   ['close_5fspan_5ftag',['close_span_tag',['../cairo_8c.html#a1e942016013e356b8ccc0c2b0168555f',1,'cairo.c']]],
   ['closedir',['closedir',['../dirent__msvc_8h.html#a748b9bd26c040c2ad9107c9d8c1aab42',1,'dirent_msvc.h']]],
   ['closelink',['Closelink',['../plframe_8c.html#a9368a6bdda2e156b19b2a8a5c73ae68b',1,'Closelink(Tcl_Interp *, PlFrame *, int, const char **):&#160;plframe.c'],['../plframe_8c.html#a6fe14f326cbce7eeba1f660ddf4a817b',1,'Closelink(Tcl_Interp *interp, register PlFrame *plFramePtr, int PL_UNUSED(argc), const char **PL_UNUSED(argv)):&#160;plframe.c'],['../plplotter_8c.html#a070064faa9a5d16232e31e30a23c6ea5',1,'Closelink(Tcl_Interp *, PlPlotter *, int, CONST char **):&#160;plplotter.c'],['../plplotter_8c.html#a7835b5f6be0ca9c1af26285c0b78c9b3',1,'Closelink(Tcl_Interp *interp, register PlPlotter *plPlotterPtr, int PL_UNUSED(argc), CONST char **PL_UNUSED(argv)):&#160;plplotter.c']]],
   ['closeqsas',['closeqsas',['../qsastime_8c.html#af39705af3d87fd254eddf83d6426513e',1,'closeqsas(QSASConfig **qsasconfig):&#160;qsastime.c'],['../qsastime_8h.html#ab9585a6cb19a4b761b49983f6f9b0c42',1,'closeqsas(QSASConfig **qsasconfig):&#160;qsastime.c']]],
   ['closeqtapp',['closeQtApp',['../qt_8cpp.html#aae3cd05e54105bbdf9fcd42eab9d0031',1,'qt.cpp']]],
-  ['cmap0_5fpalette_5fread',['cmap0_palette_read',['../plctrl_8c.html#ab881049a7e2efced50c1f34a57746369',1,'plctrl.c']]],
+  ['cmap0_5fpalette_5fread',['cmap0_palette_read',['../plctrl_8c.html#a4650085080e84595155f03c428439f90',1,'plctrl.c']]],
   ['cmd',['cmd',['../classplstream.html#a0aed09ebde7556077e59ecba2af1b2a8',1,'plstream::cmd()'],['../plframe_8c.html#a84242b21a699f489f5a1756ed9068d8c',1,'Cmd(Tcl_Interp *, PlFrame *, int, const char **):&#160;plframe.c'],['../plframe_8c.html#aeaf4c5a69bd1c21595c3213ade344a19',1,'Cmd(Tcl_Interp *interp, register PlFrame *plFramePtr, int argc, const char **argv):&#160;plframe.c'],['../plplotter_8c.html#a1471a95acc6c5b1b8d4809399a1eee3f',1,'Cmd(Tcl_Interp *, PlPlotter *, int, CONST char **):&#160;plplotter.c'],['../plplotter_8c.html#a8c3e973dd611da8284daeaa8025d9b2d',1,'Cmd(Tcl_Interp *interp, register PlPlotter *plPlotterPtr, int argc, CONST char **argv):&#160;plplotter.c']]],
-  ['col',['col',['../classplstream.html#a814d3ed5c7a45bdc5359e252bee5b6c7',1,'plstream::col(PLcolor c)'],['../classplstream.html#a145a04d677fb3192e3eb90846949e693',1,'plstream::col(PLFLT c)']]],
+  ['col',['col',['../classplstream.html#a814d3ed5c7a45bdc5359e252bee5b6c7',1,'plstream']]],
   ['col0',['col0',['../classplstream.html#a6cde7180bbc3ab9e10d3a4f4439bd785',1,'plstream']]],
   ['col1',['col1',['../classplstream.html#a943581cf5af193483948da880ee58f2e',1,'plstream']]],
-  ['color_5fset',['color_set',['../plctrl_8c.html#a2b7cea0cf3f921b8470f08bdce848db6',1,'plctrl.c']]],
+  ['color_5fset',['color_set',['../plctrl_8c.html#ac5d19944a1c85342b0e2690698e1263e',1,'plctrl.c']]],
   ['colorbar',['colorbar',['../classplstream.html#a9364f32b836a2b176a7f05101238f501',1,'plstream']]],
   ['colormanip',['ColorManip',['../plframe_8c.html#a6b6b98b8862eabbcc25f7d3c49818a34',1,'ColorManip(Tcl_Interp *, PlFrame *, int, const char **):&#160;plframe.c'],['../plframe_8c.html#af2b731bf99058598e7b0289173db73c4',1,'ColorManip(Tcl_Interp *interp, register PlFrame *plFramePtr, int argc, const char **argv):&#160;plframe.c']]],
   ['compar',['compar',['../plfill_8c.html#a68cc8023292b0ea3f252df3b1574c25e',1,'plfill.c']]],
@@ -301,16 +298,16 @@ var searchData=
   ['cont_5fstore',['cont_store',['../plcont_8c.html#aca1ec0f939fa6321ae45a5855fc16e22',1,'cont_store(PLFLT_MATRIX f, PLINT nx, PLINT ny, PLINT kx, PLINT lx, PLINT ky, PLINT ly, PLFLT_VECTOR clevel, PLINT nlevel, PLTRANSFORM_callback pltr, PLPointer pltr_data, CONT_LEVEL **contour):&#160;plcont.c'],['../plplotP_8h.html#ab31ef38f5bb56843df09bf42078665c5',1,'cont_store(PLFLT_MATRIX f, PLINT nx, PLINT ny, PLINT kx, PLINT lx, PLINT ky, PLINT ly, PLFLT_VECTOR clevel, PLINT nlevel, void(*pltr)(PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer), PLPointer pltr_data, CONT_LEVEL **contour):&#160;plplotP.h']]],
   ['cont_5fxy_5fstore',['cont_xy_store',['../plcont_8c.html#a52a71436e6b8dfbb16d2b29e48791b0f',1,'plcont.c']]],
   ['contourable_5fdata',['Contourable_Data',['../classContourable__Data.html#a8d994870c40b148f0afa2babfbd6253f',1,'Contourable_Data']]],
-  ['contourable_5fdata_5fevaluator',['Contourable_Data_evaluator',['../plstream_8cc.html#aea4325c629efa6ce4a3ac25d113cb787',1,'Contourable_Data_evaluator(PLINT i, PLINT j, PLPointer p):&#160;plstream.cc'],['../plstream_8h.html#aea4325c629efa6ce4a3ac25d113cb787',1,'Contourable_Data_evaluator(PLINT i, PLINT j, PLPointer p):&#160;plstream.cc']]],
+  ['contourable_5fdata_5fevaluator',['Contourable_Data_evaluator',['../plstream_8cc.html#aea4325c629efa6ce4a3ac25d113cb787',1,'Contourable_Data_evaluator(PLINT i, PLINT j, PLPointer p):&#160;plstream.cc'],['../plstream_8h.html#a1951493a902c37f85119c412978e70e8',1,'Contourable_Data_evaluator(PLINT i, PLINT j, PLPointer p):&#160;plstream.cc']]],
   ['convert_5farray',['convert_array',['../namespaceplplot.html#aba0627d998c5a1e8fe7e417bbb69ce7b',1,'plplot']]],
-  ['convert_5fto_5fstr',['convert_to_str',['../classoctave__swig__type.html#aecf792fe282640ed8307de1118225f83',1,'octave_swig_type::convert_to_str()'],['../classoctave__swig__ref.html#affb2689eb94515dd316a4f95a6b8029d',1,'octave_swig_ref::convert_to_str()']]],
-  ['convert_5fto_5fstr_5finternal',['convert_to_str_internal',['../classoctave__swig__type.html#a5a4cc83cb30d4dd31004e923701bdfe3',1,'octave_swig_type::convert_to_str_internal()'],['../classoctave__swig__ref.html#ac73647da3191211041a825684b911e30',1,'octave_swig_ref::convert_to_str_internal()']]],
-  ['coord_5fxform_5fevaluator',['Coord_Xform_evaluator',['../plstream_8cc.html#a3a348ecf248ba26de11828eeb6552be3',1,'Coord_Xform_evaluator(PLFLT ox, PLFLT oy, PLFLT *nx, PLFLT *ny, PLPointer p):&#160;plstream.cc'],['../plstream_8h.html#a9fb0ec4fa238dfadbaa080844be6bef1',1,'Coord_Xform_evaluator(PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer):&#160;plstream.cc']]],
-  ['copy',['copy',['../classoctave__swig__packed.html#a731b3c2045a5e98c57a5f3a53d02a263',1,'octave_swig_packed']]],
-  ['copystring2f',['copystring2f',['../classplplot__private__utilities.html#ab9d16dd4461b878edd9990eb4d499f4a',1,'plplot_private_utilities']]],
+  ['convert_5fto_5fstr',['convert_to_str',['../classoctave__swig__type.html#a04d8c1673e160bb7a9d308b830cbed5c',1,'octave_swig_type::convert_to_str()'],['../classoctave__swig__ref.html#a9d3c41a68f9b2f9cdede33926bc98062',1,'octave_swig_ref::convert_to_str()']]],
+  ['convert_5fto_5fstr_5finternal',['convert_to_str_internal',['../classoctave__swig__type.html#af71c0af2572b864f4352afff53dd95f6',1,'octave_swig_type::convert_to_str_internal()'],['../classoctave__swig__ref.html#adc55a56010ed42f018336736c6bb7106',1,'octave_swig_ref::convert_to_str_internal()']]],
+  ['coord_5fxform_5fevaluator',['Coord_Xform_evaluator',['../plstream_8cc.html#a3a348ecf248ba26de11828eeb6552be3',1,'Coord_Xform_evaluator(PLFLT ox, PLFLT oy, PLFLT *nx, PLFLT *ny, PLPointer p):&#160;plstream.cc'],['../plstream_8h.html#a527d38976b14dad3b413fc2dd7a884df',1,'Coord_Xform_evaluator(PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer):&#160;plstream.cc']]],
+  ['copy',['copy',['../classoctave__swig__packed.html#ae2ef561e6dfd97f09dce929b6bfcc794',1,'octave_swig_packed']]],
+  ['copystring2f',['copystring2f',['../namespaceplplot__private__utilities.html#ab9d16dd4461b878edd9990eb4d499f4a',1,'plplot_private_utilities']]],
   ['cpp_5fptr',['cpp_ptr',['../structoctave__swig__type_1_1cpp__ptr.html#a675a130f155afd17c25c60dddfd7162f',1,'octave_swig_type::cpp_ptr']]],
-  ['cpstrm',['cpstrm',['../classplstream.html#ab24f6d2d81f77b70cc8c2ca34c38973c',1,'plstream::cpstrm(plstream &amp;pls, bool flags)'],['../classplstream.html#ac13e957141a49f30c8c659193d17446c',1,'plstream::cpstrm(plstream &amp;pls, PLINT flags)']]],
-  ['create',['create',['../classPLMemoryMap.html#aad0d3a12211797e242f25666b99f2066',1,'PLMemoryMap::create()'],['../classPLNamedMutex.html#a7151127622175d2731ecbb49c453c9ec',1,'PLNamedMutex::create()'],['../classwxPLplotstream.html#af248a283d04a83fbb83661a7c0a4b61e',1,'wxPLplotstream::Create()']]],
+  ['cpstrm',['cpstrm',['../classplstream.html#ab24f6d2d81f77b70cc8c2ca34c38973c',1,'plstream']]],
+  ['create',['Create',['../classwxPLplotstream.html#af248a283d04a83fbb83661a7c0a4b61e',1,'wxPLplotstream::Create()'],['../classPLMemoryMap.html#aad0d3a12211797e242f25666b99f2066',1,'PLMemoryMap::create()'],['../classPLNamedMutex.html#a7151127622175d2731ecbb49c453c9ec',1,'PLNamedMutex::create()']]],
   ['create_5fstring',['create_string',['../aqt_8c.html#a56843721c7bb07273acc80ccf8eadeb6',1,'aqt.c']]],
   ['createfont',['createFont',['../classFont.html#a5f9dd24c29cb14f8083cc47e803a2106',1,'Font']]],
   ['createrband',['CreateRband',['../plframe_8c.html#a497652ae8700c5640d1d59d274eec3a6',1,'CreateRband(PlFrame *):&#160;plframe.c'],['../plplotter_8c.html#a9ec3611762c264aecbde987d78ad3925',1,'CreateRband(PlPlotter *):&#160;plplotter.c']]],
