@@ -25,7 +25,7 @@ var searchData=
   ['xmax_5fdev',['xmax_dev',['../structPLDev.html#a8d33f07b5696b26dbe2ed8648cbeec93',1,'PLDev::xmax_dev()'],['../structPSDev.html#a50af04cad55e158e195fe0d96029bdba',1,'PSDev::xmax_dev()']]],
   ['xmin',['xmin',['../structcsa.html#a005399c1a1a23bcf46c2f4ed3acc70bd',1,'csa::xmin()'],['../structdelaunay.html#adfaa7a8743255547db60acdf55a90b96',1,'delaunay::xmin()'],['../structPLStrip.html#a952a2f41f34f9295ad7c29c9fc2ea950',1,'PLStrip::xmin()'],['../structPLRDev.html#adc1db0719f2952bc0152fc50c2e50302',1,'PLRDev::xmin()'],['../structPLmDev.html#aebd0f535a8753477736ffcf8302e0e2f',1,'PLmDev::xmin()'],['../structIMG__DT.html#a2a967ce77593f3362dda17c0c7385ff9',1,'IMG_DT::xmin()'],['../structPLDev.html#aff0304a2dcc0db26abbec401b5eb25c6',1,'PLDev::xmin()'],['../structPSDev.html#a726f94977509580d43eec85fb5d30f59',1,'PSDev::xmin()']]],
   ['xmin_5fdev',['xmin_dev',['../structPLDev.html#a4be70c9c75177f43ac2500903dfde560',1,'PLDev::xmin_dev()'],['../structPSDev.html#add0168298b323516c82e0bc4bc13983b',1,'PSDev::xmin_dev()']]],
-  ['xoffset',['xOffset',['../classQtPLDriver.html#aa5459c458d794c0536fdde23d059406d',1,'QtPLDriver::xOffset()'],['../structPLStream.html#a59aa7205e849ddd9b67c95420bf3bffe',1,'PLStream::xoffset()']]],
+  ['xoffset',['xoffset',['../structPLStream.html#a59aa7205e849ddd9b67c95420bf3bffe',1,'PLStream::xoffset()'],['../classQtPLDriver.html#aa5459c458d794c0536fdde23d059406d',1,'QtPLDriver::xOffset()']]],
   ['xold',['xold',['../structPLRDev.html#a1b93a8aba2e97f23d7b031a5a224baed',1,'PLRDev::xold()'],['../structTkDev.html#a73901cd7a8e8278fc8dd96f2a1fcbeb6',1,'TkDev::xold()'],['../structPLmDev.html#aef98ee70a88c95f339a4f32b9bd38468',1,'PLmDev::xold()'],['../structPLDev.html#ab71f661ba3049e35e4ee427050d25b10',1,'PLDev::xold()'],['../structPSDev.html#a9753ff4a7c6ea93ba7ea8fca2cf67462',1,'PSDev::xold()']]],
   ['xorgc',['xorGC',['../structPlFrame.html#a3c44e36073bc6376f90f5fcbe4b87fab',1,'PlFrame::xorGC()'],['../structPlPlotter.html#a343431d349fd3ae0f118fc3773144c17',1,'PlPlotter::xorGC()']]],
   ['xpmm',['xpmm',['../structPLStream.html#af2865bcc032aafba071341ba183d6c39',1,'PLStream']]],
