@@ -1,7 +1,11 @@
 var searchData=
 [
-  ['c_5fplcgrid',['c_PLcGrid',['../classplplot.html#ae0952584f6d3334a3314373e9de68ab2',1,'plplot']]],
-  ['c_5fplcgrid2',['c_PLcGrid2',['../classplplot.html#ac0a3be6d22835e74179254e1635499bc',1,'plplot']]],
+  ['c',['C',['../namespaceplplot.html#aea2545117331b1b23d6084803c704478',1,'plplot']]],
+  ['c1',['c1',['../structPLControlPt.html#a1dba38063cf7e0715477cd6547f289ad',1,'PLControlPt']]],
+  ['c2',['c2',['../structPLControlPt.html#a5807db3f5421dea3724d9670532bc19b',1,'PLControlPt']]],
+  ['c3',['c3',['../structPLControlPt.html#a600b3cab85525d717e054baa8d731038',1,'PLControlPt']]],
+  ['c_5fplcgrid',['c_PLcGrid',['../namespaceplplot.html#ae0952584f6d3334a3314373e9de68ab2',1,'plplot']]],
+  ['c_5fplcgrid2',['c_PLcGrid2',['../namespaceplplot.html#ac0a3be6d22835e74179254e1635499bc',1,'plplot']]],
   ['cached',['cached',['../structDIR.html#a3a41d5f8c72e7d7100c0259f375d2993',1,'DIR']]],
   ['cairo_5foptions',['cairo_options',['../cairo_8c.html#a23dccfc537aefb11001af1e2033a7fa2',1,'cairo.c']]],
   ['cairocontext',['cairoContext',['../structPLCairo.html#af332c5800cda1a2db4dffef2345ae4a3',1,'PLCairo']]],
@@ -25,17 +29,18 @@ var searchData=
   ['client_5fhost',['client_host',['../plserver_8c.html#aafade1970b63a62fc7e25cc58d4c7927',1,'plserver.c']]],
   ['client_5fname',['client_name',['../plserver_8c.html#ac31d6d1fcf75f9fd1e0c65bbab284d49',1,'plserver.c']]],
   ['client_5fport',['client_port',['../plserver_8c.html#ae182f91946d7b87506442ed3f37f2cfb',1,'plserver.c']]],
-  ['clientdata',['clientdata',['../structswig__type__info.html#a2e1f9087e639dd7c8c131fbc6e399194',1,'swig_type_info::clientdata()'],['../structswig__module__info.html#a39999692b76f191b66a5ce746681dc84',1,'swig_module_info::clientdata()'],['../structCommand.html#a20ac86c445651c87898cf7802e2324a2',1,'Command::clientData()']]],
+  ['clientdata',['clientData',['../structCommand.html#a20ac86c445651c87898cf7802e2324a2',1,'Command::clientData()'],['../structswig__type__info.html#a2e1f9087e639dd7c8c131fbc6e399194',1,'swig_type_info::clientdata()'],['../structswig__module__info.html#a39999692b76f191b66a5ce746681dc84',1,'swig_module_info::clientdata()']]],
   ['clpxma',['clpxma',['../structPLStream.html#ac6e99ff104e7775673bf6cc3a520151a',1,'PLStream']]],
   ['clpxmi',['clpxmi',['../structPLStream.html#ac1cb48c958c8a95ecb08a84106843953',1,'PLStream']]],
   ['clpyma',['clpyma',['../structPLStream.html#a54d54311cae100f303fe6c1f74181639',1,'PLStream']]],
   ['clpymi',['clpymi',['../structPLStream.html#a1579b4aa16d0d6656c60b6140d71bc29',1,'PLStream']]],
-  ['cls_5fstatic',['cls_static',['../structswig__lua__class.html#adedac07dcb35b9a35d2cc1390d36a753',1,'swig_lua_class']]],
+  ['cls_5fstatic',['cls_static',['../structswig__lua__class.html#a41b17587e0b26e2112200adfffb22730',1,'swig_lua_class']]],
   ['cmap0',['cmap0',['../structTkwDisplay.html#a73cfdca12037d134b116c27b086d453b',1,'TkwDisplay::cmap0()'],['../structPLStream.html#a2cfea596db61b202941a2493c44fe609',1,'PLStream::cmap0()'],['../structXwDisplay.html#a730003c70ffced20691703ba8a0c253b',1,'XwDisplay::cmap0()']]],
   ['cmap1',['cmap1',['../structTkwDisplay.html#ae22e700c879ed55e39fe9d4d3719f3b1',1,'TkwDisplay::cmap1()'],['../structPLStream.html#abfb11a827bc7132ff5d27adde749912a',1,'PLStream::cmap1()'],['../structXwDisplay.html#add7434ff5062a982e1bb210d25422610',1,'XwDisplay::cmap1()']]],
   ['cmap1_5fmax',['cmap1_max',['../structPLStream.html#acfaba83b23c3137edac8768b9cc4dc59',1,'PLStream']]],
   ['cmap1_5fmin',['cmap1_min',['../structPLStream.html#a38aa4072d8dd697e1220bed77b4748e8',1,'PLStream']]],
   ['cmap1cp',['cmap1cp',['../structPLStream.html#ad2c579c767880b5fd0a80be14c039411',1,'PLStream']]],
+  ['cmap1cp_5fis_5frgb',['cmap1cp_is_rgb',['../structPLStream.html#a56fbb6d1b8bb0d54d524cd9af4f694ca',1,'PLStream']]],
   ['cmd',['cmd',['../structplplot_1_1__N11.html#ada7f7976ca742a2e6306d7d850d2b286',1,'plplot::_N11::cmd()'],['../structtclMatrixXtnsnDescr.html#a4500e93e11a08db69584e9263a6f528c',1,'tclMatrixXtnsnDescr::cmd()'],['../structPLBufferingCB.html#ab3e77a6ccb3f11035c134cda510faabb',1,'PLBufferingCB::cmd()']]],
   ['cmdbuf',['cmdbuf',['../structTkDev.html#a94c2333d62e0dc364760cbc8878084bd',1,'TkDev']]],
   ['cmdbuf_5flen',['cmdbuf_len',['../structTkDev.html#a23750a0f857d6089fd998bfb60b42b98',1,'TkDev']]],
@@ -47,7 +52,7 @@ var searchData=
   ['colbox',['colbox',['../structPLStrip.html#a3bf05498eb14d3500b5847adcdc7c708',1,'PLStrip']]],
   ['collab',['collab',['../structPLStrip.html#a894dbc23d06f4ce3309994bc3224905c',1,'PLStrip']]],
   ['colline',['colline',['../structPLStrip.html#a43ac7953a16fc0f2e0ea2b1108256ada',1,'PLStrip']]],
-  ['color',['color',['../structTkwDisplay.html#a72bf92a255cc92a519ae3b425b574a42',1,'TkwDisplay::color()'],['../structPLStream.html#a52d57f1786f9f7f58de8eb4dd7eb331c',1,'PLStream::color()'],['../structXwDisplay.html#a798c2fcc03531d090bf8633c60f07db2',1,'XwDisplay::color()']]],
+  ['color',['color',['../structTkwDisplay.html#a72bf92a255cc92a519ae3b425b574a42',1,'TkwDisplay::color()'],['../structPLStream.html#a52d57f1786f9f7f58de8eb4dd7eb331c',1,'PLStream::color()'],['../structXwDisplay.html#a798c2fcc03531d090bf8633c60f07db2',1,'XwDisplay::color()'],['../ps_8c.html#a0fd02fb9277ffcb35a75066ffe95e8c7',1,'color():&#160;ps.c'],['../psttf_8cc.html#a0fd02fb9277ffcb35a75066ffe95e8c7',1,'color():&#160;psttf.cc']]],
   ['colorset',['colorset',['../structPLStream.html#adce35c7a87b6176fdb78008be0ea1ba3',1,'PLStream']]],
   ['colorstotal',['colorsTotal',['../structcdImageStruct.html#aa22fa3418f52a38c913c847346a0177f',1,'cdImageStruct']]],
   ['command',['command',['../tkMain_8c.html#a59f3f96d8bcfba6631bce1a4d1594229',1,'tkMain.c']]],
