@@ -5,8 +5,8 @@ var searchData=
   ['gc',['gc',['../structTkwDev.html#a8166e22ee1368fcea258b52224ef1878',1,'TkwDev::gc()'],['../structXwDev.html#a5476a3dc986ba91f5491f7e9f63e3ae1',1,'XwDev::gc()']]],
   ['gcxor',['gcXor',['../structTkwDisplay.html#a31baa71129de5785caaa7f5dbd2fc2bb',1,'TkwDisplay::gcXor()'],['../structXwDisplay.html#ad215e4872240e5a3464a7591aa608ac1',1,'XwDisplay::gcXor()']]],
   ['geometry',['geometry',['../structPLStream.html#a7844488c645193fee1f5e1f31df9798e',1,'PLStream::geometry()'],['../tkMain_8c.html#a3512ed15de220f178dc26334564c6463',1,'geometry():&#160;tkMain.c']]],
-  ['get',['get',['../structtclMatrix.html#a33d2abf4f0d6e86fcfdf32a333265b12',1,'tclMatrix::get()'],['../structplf2ops__t.html#a5e06163958c53e58712d8a76d6918b40',1,'plf2ops_t::get()'],['../structswig__lua__var__info.html#a56fb0b689f37015e340b35c6d7ee0b99',1,'swig_lua_var_info::get()']]],
-  ['get_5fattr',['get_attr',['../structswig__globalvar.html#a051e346d0cd7608bf99e96726022e88c',1,'swig_globalvar']]],
+  ['get',['get',['../structtclMatrix.html#a1f07da9a87e675b7349e09253dcafbce',1,'tclMatrix::get()'],['../structplf2ops__t.html#a3d2ca85ae97972e8b4d6e0221aaedc27',1,'plf2ops_t::get()'],['../structswig__lua__var__info.html#a56fb0b689f37015e340b35c6d7ee0b99',1,'swig_lua_var_info::get()']]],
+  ['get_5fattr',['get_attr',['../structswig__globalvar.html#ab617d0ca02f7660a9e5fd31dceaf6475',1,'swig_globalvar']]],
   ['get_5fmethod',['get_method',['../structswig__octave__member.html#afc6d3dc3d5c938d5a29f53fb7237ea5a',1,'swig_octave_member']]],
   ['get_5fstring_5flength',['get_string_length',['../structPLStream.html#a97ec49d30120b332e4f9246019bc9800',1,'PLStream']]],
   ['getmethod',['getmethod',['../structswig__lua__attribute.html#ab18a92c81433b7b3de23856cda4b89b5',1,'swig_lua_attribute']]],
@@ -16,10 +16,10 @@ var searchData=
   ['graphicsin',['graphicsIn',['../structMemoryMapHeader.html#ae4905de4351f1c48da7b902a5cca0920',1,'MemoryMapHeader']]],
   ['graphx',['graphx',['../structPLStream.html#ac97c1d9507b3b316c557f166eca17430',1,'PLStream']]],
   ['green',['green',['../structcdImageStruct.html#afdfee0cfe98ddb62dd049d97c6285695',1,'cdImageStruct']]],
-  ['grid_5fcsa',['GRID_CSA',['../classplplot.html#ac7e8d796ea6f9dd2556a6212cdf0dba7',1,'plplot::GRID_CSA()'],['../namespaceplplotc.html#a637c93aafb8a043eafe6e45e4c8fe7fe',1,'plplotc.GRID_CSA()'],['../namespaceplplotc__fixed.html#a48833f81bde3cf17d99b5774751d2e9a',1,'plplotc_fixed.GRID_CSA()']]],
-  ['grid_5fdtli',['GRID_DTLI',['../classplplot.html#a69350e251c909eb5d9dc20469b532bcb',1,'plplot::GRID_DTLI()'],['../namespaceplplotc.html#a9c46b3ae31f7775cc68888dfe0dd5009',1,'plplotc.GRID_DTLI()'],['../namespaceplplotc__fixed.html#a2ad8fb126c83458eaa7c86a361997b04',1,'plplotc_fixed.GRID_DTLI()']]],
-  ['grid_5fnnaidw',['GRID_NNAIDW',['../classplplot.html#a14854e59f92a3552380e29a55d06622f',1,'plplot::GRID_NNAIDW()'],['../namespaceplplotc.html#a41083538b2b79e26bb68ceb7f1bd7220',1,'plplotc.GRID_NNAIDW()'],['../namespaceplplotc__fixed.html#a5bb69d831536a32008ec1aff57d8af82',1,'plplotc_fixed.GRID_NNAIDW()']]],
-  ['grid_5fnni',['GRID_NNI',['../classplplot.html#aae7efb1735fa85ed208db2d57f2d0b48',1,'plplot::GRID_NNI()'],['../namespaceplplotc.html#a3017ccbfedf84973d1eb6c1def54bdc1',1,'plplotc.GRID_NNI()'],['../namespaceplplotc__fixed.html#a64b1a61da40a67250b6a4745bc86dc6a',1,'plplotc_fixed.GRID_NNI()']]],
-  ['grid_5fnnidw',['GRID_NNIDW',['../classplplot.html#a1acbbb4c8a1b2da431aafe9b0383a8d1',1,'plplot::GRID_NNIDW()'],['../namespaceplplotc.html#a9dadd7e9c8534b465792964bd952766c',1,'plplotc.GRID_NNIDW()'],['../namespaceplplotc__fixed.html#a2dd8f3c42f3dc1d4ab1fd0b61d5caceb',1,'plplotc_fixed.GRID_NNIDW()']]],
-  ['grid_5fnnli',['GRID_NNLI',['../classplplot.html#ae46f869cff5269e5ddac49fbf11f8ff5',1,'plplot::GRID_NNLI()'],['../namespaceplplotc.html#aed82e9f2bf7583a3528d1eeb494423af',1,'plplotc.GRID_NNLI()'],['../namespaceplplotc__fixed.html#aab72e712e85678087a67ec91801a570c',1,'plplotc_fixed.GRID_NNLI()']]]
+  ['grid_5fcsa',['GRID_CSA',['../namespaceplplot.html#ac7e8d796ea6f9dd2556a6212cdf0dba7',1,'plplot::GRID_CSA()'],['../namespaceplplotc.html#a00dc056fe56ebe194647cbd1162e343c',1,'plplotc.GRID_CSA()']]],
+  ['grid_5fdtli',['GRID_DTLI',['../namespaceplplot.html#a69350e251c909eb5d9dc20469b532bcb',1,'plplot::GRID_DTLI()'],['../namespaceplplotc.html#ac14adf4dbaa8066db6c3ba43dcb3e2f8',1,'plplotc.GRID_DTLI()']]],
+  ['grid_5fnnaidw',['GRID_NNAIDW',['../namespaceplplot.html#a14854e59f92a3552380e29a55d06622f',1,'plplot::GRID_NNAIDW()'],['../namespaceplplotc.html#ac3170cbecddcf4693801fffa3d313993',1,'plplotc.GRID_NNAIDW()']]],
+  ['grid_5fnni',['GRID_NNI',['../namespaceplplot.html#aae7efb1735fa85ed208db2d57f2d0b48',1,'plplot::GRID_NNI()'],['../namespaceplplotc.html#a8ce11df5f81041361d9a7da90c273424',1,'plplotc.GRID_NNI()']]],
+  ['grid_5fnnidw',['GRID_NNIDW',['../namespaceplplot.html#a1acbbb4c8a1b2da431aafe9b0383a8d1',1,'plplot::GRID_NNIDW()'],['../namespaceplplotc.html#ad49fbf71d1599309e9d51e5f7abb0f85',1,'plplotc.GRID_NNIDW()']]],
+  ['grid_5fnnli',['GRID_NNLI',['../namespaceplplot.html#ae46f869cff5269e5ddac49fbf11f8ff5',1,'plplot::GRID_NNLI()'],['../namespaceplplotc.html#ac3ae103afcb084bddb043b6ab48b552b',1,'plplotc.GRID_NNLI()']]]
 ];
