@@ -1,8 +1,8 @@
 var searchData=
 [
-  ['h',['h',['../structtriangle.html#a82dbd6f31285b6c60e4c035417c6716b',1,'triangle::h()'],['../structcsa.html#acba79cb4f4eb19929c067cf52e145131',1,'csa::h()'],['../structplplot_1_1__N10.html#ae099434248d49c9374af650a07cf4b10',1,'plplot::_N10::h()'],['../structPLControlPt.html#a73674db8c26cba9caffc05e49c55e6cd',1,'PLControlPt::h()']]],
+  ['h',['h',['../structtriangle.html#a82dbd6f31285b6c60e4c035417c6716b',1,'triangle::h()'],['../structcsa.html#acba79cb4f4eb19929c067cf52e145131',1,'csa::h()'],['../structplplot_1_1__N10.html#ae099434248d49c9374af650a07cf4b10',1,'plplot::_N10::h()']]],
   ['hack',['hack',['../structPLStream.html#ac98930296aded0072e2beaeb4c8dcdbd',1,'PLStream']]],
-  ['handler',['handler',['../structPLOptionTable.html#a6046671ce05cea570f5eda5e64d84b55',1,'PLOptionTable']]],
+  ['handler',['handler',['../structPLOptionTable.html#acd8d1de9686c376de8b7b0f7ed62bb58',1,'PLOptionTable']]],
   ['has_5fstring_5flength',['has_string_length',['../structPLStream.html#abb61b1a584d5cbce8a389a7df736cd9b',1,'PLStream']]],
   ['hasalpha',['hasAlpha',['../aqt_8c.html#ae34bdcef7e730aa1e350245620013128',1,'aqt.c']]],
   ['hascoeffs',['hascoeffs',['../structtriangle.html#a76fa4a762d76a9c09436bbaca8153dbf',1,'triangle']]],
@@ -15,6 +15,7 @@ var searchData=
   ['hershey_5fto_5funicode_5flookup_5ftable',['hershey_to_unicode_lookup_table',['../plplotP_8h.html#a018bc4e28f0a17e8e928a7815f866b43',1,'hershey_to_unicode_lookup_table():&#160;plhershey-unicode.h'],['../plhershey-unicode_8h.html#a1aa0c83f54d4d4823a76ab89ac80ce16',1,'hershey_to_unicode_lookup_table():&#160;plhershey-unicode.h']]],
   ['hinstlib',['hinstLib',['../struct____dlhandle.html#ad612da9abe95210282423ac7bd98bfa4',1,'__dlhandle']]],
   ['hlp_5fmsg',['hlp_msg',['../structDrvOpt.html#a9cd6db0ab3890fc564ddab8e769db4c0',1,'DrvOpt']]],
+  ['hrshsym',['hrshsym',['../ps_8c.html#ab35ca6889f9da6282a44b2a15c70e076',1,'hrshsym():&#160;ps.c'],['../psttf_8cc.html#ab35ca6889f9da6282a44b2a15c70e076',1,'hrshsym():&#160;psttf.cc']]],
   ['ht_5fdata',['ht_data',['../structnnhpi.html#a126ee669cab3462cbc52b7a329beaba1',1,'nnhpi']]],
   ['ht_5fweights',['ht_weights',['../structnnhpi.html#ac51966e4ed100e61f47fbf3887a19a7b',1,'nnhpi']]]
 ];
