@@ -6,6 +6,7 @@ var searchData=
   ['m_5fbuffer',['m_buffer',['../classPLMemoryMap.html#a40fe6923314fcefd4f239590eb91c470',1,'PLMemoryMap']]],
   ['m_5fcanvascolour',['m_canvasColour',['../classwxPLplotwindow.html#a56a3fc5e70ab0b4288d405eba3221103',1,'wxPLplotwindow']]],
   ['m_5fclipeverything',['m_clipEverything',['../classClipper.html#a1a095f85f1fcd4b3edb376b49524eb25',1,'Clipper']]],
+  ['m_5fcompletedfirstrender',['m_completedFirstRender',['../classwxPLplotwindow.html#adaf0ac116110117160cf12032693bb92',1,'wxPLplotwindow']]],
   ['m_5fcreated',['m_created',['../classwxPLplotstream.html#abc3aab2b6b629049a6d0ac69ad6d7581',1,'wxPLplotstream::m_created()'],['../classwxPLplotwindow.html#ae146662e19866daab2746062529f6da6',1,'wxPLplotwindow::m_created()']]],
   ['m_5fdc',['m_dc',['../classwxPLDevice.html#afc1d2a710f600ff2880f37c54ea46e00',1,'wxPLDevice::m_dc()'],['../classScaler.html#a59bf721f4717c535c13889518b18efd6',1,'Scaler::m_dc()'],['../classOriginChanger.html#ad7c43a1f94266d8b434365df5d6807e1',1,'OriginChanger::m_dc()'],['../classDrawingObjectsChanger.html#a9f006e26b396936809f5b77453b44624',1,'DrawingObjectsChanger::m_dc()'],['../classTextObjectsSaver.html#adb0494be3b8ae1b2e1d085f4079ea58f',1,'TextObjectsSaver::m_dc()'],['../classClipper.html#aaf597ece37e08c7a615b29f52fb101ae',1,'Clipper::m_dc()']]],
   ['m_5fdheight',['m_dHeight',['../classQtPLDriver.html#a8331eefe652858a5d055faede0342117',1,'QtPLDriver']]],
@@ -43,6 +44,9 @@ var searchData=
   ['m_5fprevsymboldepth',['m_prevSymbolDepth',['../classPlDevice.html#a48c0b2f17fca05d1044d2a05ffa08191',1,'PlDevice']]],
   ['m_5fprevsymbolheight',['m_prevSymbolHeight',['../classPlDevice.html#a6b53b14849e41acc9d14fd64326913d9',1,'PlDevice']]],
   ['m_5fprevsymbolwidth',['m_prevSymbolWidth',['../classPlDevice.html#ae23d9a79a0d29fdcfb6cc3e4006203ed',1,'PlDevice']]],
+  ['m_5frendertimer',['m_renderTimer',['../classwxPLplotwindow.html#a0a0311aad5868724e2e2bb354f6a530a',1,'wxPLplotwindow']]],
+  ['m_5fresizerenderdelay',['m_resizeRenderDelay',['../classwxPLplotwindow.html#ab4ccae324d7f297aba5c4c7e0631cd2c',1,'wxPLplotwindow']]],
+  ['m_5fresizing',['m_resizing',['../classwxPLplotwindow.html#a0aae6eeecc957a6a44b35e3dd6a40b61',1,'wxPLplotwindow']]],
   ['m_5fsaver',['m_saver',['../classTextObjectsChanger.html#ac69ea29fe1df7b53b55704db0e772209',1,'TextObjectsChanger']]],
   ['m_5fscale',['m_scale',['../classwxPLDevice.html#a50279c0d07a7533de040944191d18e95',1,'wxPLDevice']]],
   ['m_5fseed',['m_seed',['../classRand.html#ac0f529d022a39fbfaf5cd6c8a7c6b41b',1,'Rand']]],
@@ -63,7 +67,7 @@ var searchData=
   ['m_5fyoriginold',['m_yOriginOld',['../classOriginChanger.html#a78bfce06a7967fe23fd9144c22a57c58',1,'OriginChanger']]],
   ['m_5fyscale',['m_yScale',['../classwxPLDevice.html#a02e7a573c63488a6b0fe4f984a6b9cb7',1,'wxPLDevice']]],
   ['m_5fyscaleold',['m_yScaleOld',['../classScaler.html#a2b833d6ba6585e0902a8a85c19fdf830',1,'Scaler']]],
-  ['mag_5fcolor',['MAG_COLOR',['../classplplot.html#ac50f05d8a58f2960cfe2a496d11fcad0',1,'plplot::MAG_COLOR()'],['../namespaceplplotc.html#a00cc4c7170501708af758b576e756ebd',1,'plplotc.MAG_COLOR()'],['../namespaceplplotc__fixed.html#a39d4dd0d9b29bd72e00fec13ecd9ac93',1,'plplotc_fixed.MAG_COLOR()']]],
+  ['mag_5fcolor',['MAG_COLOR',['../namespaceplplot.html#ac50f05d8a58f2960cfe2a496d11fcad0',1,'plplot::MAG_COLOR()'],['../namespaceplplotc.html#aa4b8fceedde05716ae6f5ac30c62a173',1,'plplotc.MAG_COLOR()']]],
   ['majdef',['majdef',['../structPLStream.html#aacf7dc5832d875092cda05b39b5bab87',1,'PLStream']]],
   ['majht',['majht',['../structPLStream.html#aa2981115099d54a0bde1385b2f924ba1',1,'PLStream']]],
   ['map',['map',['../structTkwDisplay.html#a38447f7530a2bd88c44a66c8648640bb',1,'TkwDisplay::map()'],['../structXwDisplay.html#a33de88b20022123ff48d63d9140485e1',1,'XwDisplay::map()']]],
@@ -72,21 +76,25 @@ var searchData=
   ['mark',['mark',['../structline.html#aaf91bfecefdf672464ae2770354b513d',1,'line::mark()'],['../structPLStream.html#a79ee5c5d824a379d4f425f2b0f59b0ce',1,'PLStream::mark()']]],
   ['markerspec',['markerspec',['../structcdImageStruct.html#a6b020d74fb7617afe9af0660ce2759e4',1,'cdImageStruct']]],
   ['masterdevice',['masterDevice',['../classMasterHandler.html#a06e1664ac4084b34591d0dff946ed0ee',1,'MasterHandler']]],
-  ['mastereh',['MasterEH',['../structTkwDev.html#aa7bc5c6dde8de561668b0919757d3de1',1,'TkwDev::MasterEH()'],['../structXwDev.html#a9ad5c3f1ab3a69618f6c4b8dd3712d6c',1,'XwDev::MasterEH()']]],
+  ['mastereh',['MasterEH',['../structTkwDev.html#a6e08c1095b1eaf5238fd8783661895f2',1,'TkwDev::MasterEH()'],['../structXwDev.html#a0698157daaf9b720ff0d554f8fb01a74',1,'XwDev::MasterEH()']]],
   ['mattable',['matTable',['../tclMatrix_8c.html#aae555c4f130e4b591c66a9096535a0ac',1,'tclMatrix.c']]],
   ['mattable_5finitted',['matTable_initted',['../tclMatrix_8c.html#a19fee3476426a6ec5696b2a040ec1b95',1,'tclMatrix.c']]],
   ['max',['max',['../classRand.html#a7e0ea4d6900b3bc0105018b3089494a0',1,'Rand']]],
   ['max_5finstr',['max_instr',['../structTkDev.html#a2e4c1b803e76c785b11ab83f0885d805',1,'TkDev::max_instr()'],['../structTkwDev.html#a80b01a0e2519a031b79e2086800ab1ff',1,'TkwDev::max_instr()'],['../structXwDev.html#ac7792e628a37239247220c22f83b92de',1,'XwDev::max_instr()']]],
+  ['max_5fplflt_5falpha',['MAX_PLFLT_ALPHA',['../namespaceplplotc.html#ab1474f8948e23e422d68cd731209db54',1,'plplotc']]],
+  ['max_5fplflt_5fcmap1',['MAX_PLFLT_CMAP1',['../namespaceplplotc.html#abf0513fac36de7636ff20d4cb0ac0ad1',1,'plplotc']]],
+  ['max_5fplint_5frgb',['MAX_PLINT_RGB',['../namespaceplplotc.html#a7edcf604ac107cbe8020d348e344b7cd',1,'plplotc']]],
   ['max_5fpoints',['max_points',['../plshade_8c.html#a77efcd267dd75021a2e449bed4f91a48',1,'plshade.c']]],
   ['max_5fpts',['max_pts',['../plshade_8c.html#aa4cb4bf8bca0b78023e5c431e2197019',1,'plshade.c']]],
-  ['maxlen',['maxlen',['../classplplot.html#a0771bb612935378464fba135a16618b8',1,'plplot']]],
+  ['maxlen',['maxlen',['../namespaceplplot.html#a0771bb612935378464fba135a16618b8',1,'plplot']]],
   ['maxwindows',['maxWindows',['../aqt_8c.html#add35f59d1173233ffee14c9fa4b97b09',1,'aqt.c']]],
   ['mcolor',['mcolor',['../structcdImageStruct.html#a02d35327105bdc1290111c2a7366888b',1,'cdImageStruct']]],
   ['member',['member',['../structPLStream.html#a47c3d2d47d3c0b105beb0981c5634d15',1,'PLStream']]],
   ['members',['members',['../structswig__octave__class.html#a0edef1ae878ed2e5b8bf9b4786b20f50',1,'swig_octave_class::members()'],['../classoctave__swig__type.html#a4d82069a306cab732e161b58c1d2919f',1,'octave_swig_type::members()']]],
-  ['mesh',['MESH',['../classplplot.html#a0a7a72416f1a62cbc7d6ed176f0889a0',1,'plplot::MESH()'],['../namespaceplplotc.html#a802cc0c25dc3ff6d58524decb1a5b9ce',1,'plplotc.MESH()'],['../namespaceplplotc__fixed.html#a36bc1fb14dfb3205004892873596350c',1,'plplotc_fixed.MESH()']]],
+  ['mesh',['MESH',['../namespaceplplot.html#a0a7a72416f1a62cbc7d6ed176f0889a0',1,'plplot::MESH()'],['../namespaceplplotc.html#a0165fba5e5a5eee4b396d9878b7e8850',1,'plplotc.MESH()']]],
   ['metafile_5fformat',['metafile_format',['../plmetafile_8c.html#a1763b8861c8032fdd2606dc6fd8685d4',1,'plmetafile.c']]],
-  ['method',['method',['../structswig__lua__method.html#acd3407541fc11f75433c4525b6be1c80',1,'swig_lua_method::method()'],['../structswig__octave__member.html#a92f709e4fb4bb8a48198939f2e2c549b',1,'swig_octave_member::method()']]],
+  ['metatable',['metatable',['../structswig__lua__class.html#a7c56e45895444992b6a42c60ba6a17e5',1,'swig_lua_class']]],
+  ['method',['method',['../structswig__octave__member.html#a92f709e4fb4bb8a48198939f2e2c549b',1,'swig_octave_member']]],
   ['methods',['methods',['../structswig__lua__class.html#ae0d9f30a8114623b1185b5907fc60719',1,'swig_lua_class']]],
   ['mf_5finfile',['mf_infile',['../structPLStream.html#a8697ddd687cd34315ba3765b196a778d',1,'PLStream']]],
   ['mf_5foutfile',['mf_outfile',['../structPLStream.html#afbc50e220f997c43679386a043a25ec2',1,'PLStream']]],
@@ -96,12 +104,14 @@ var searchData=
   ['mfpcyb',['mfpcyb',['../structPLmDev.html#acbc0c3abc51a20a658fd6d025fb4f65b',1,'PLmDev']]],
   ['mhi',['mhi',['../plot3d_8c.html#a38796a973adb2afe32e23664bb8cd944',1,'plot3d.c']]],
   ['middle',['middle',['../structtriangle.html#aecd8e3f1c9a8e096c78278db631809c0',1,'triangle']]],
+  ['min_5fplflt_5falpha',['MIN_PLFLT_ALPHA',['../namespaceplplotc.html#a302d63286fbe2d8d2114ef17c2b35b19',1,'plplotc']]],
+  ['min_5fplflt_5fcmap1',['MIN_PLFLT_CMAP1',['../namespaceplplotc.html#a9a6764fa4d9f4d66e04e1343ddfd14b4',1,'plplotc']]],
+  ['min_5fplint_5frgb',['MIN_PLINT_RGB',['../namespaceplplotc.html#a9c70f052d8bf32897d4f95d702f96091',1,'plplotc']]],
   ['min_5fpoints',['min_points',['../plshade_8c.html#a3f20636148fdd94d52564127774875d7',1,'plshade.c']]],
   ['min_5fpts',['min_pts',['../plshade_8c.html#a8a55dd46645e4e0d89cdb940b926c7ba',1,'plshade.c']]],
   ['mindef',['mindef',['../structPLStream.html#a3877166126904e55715aebbcf84e6ed6',1,'PLStream']]],
   ['minht',['minht',['../structPLStream.html#ae7f22f1bf0f3acd6c4293c40bb8ac0a6',1,'PLStream']]],
-  ['minmax',['minmax',['../structplf2ops__t.html#a43ec4eba641300e4dae7a4081c821747',1,'plf2ops_t']]],
-  ['minmax2dgrid',['MinMax2dGrid',['../classplplot.html#a22297be3066bb6e8e6330143ac0d00e4',1,'plplot']]],
+  ['minmax',['minmax',['../structplf2ops__t.html#a064ee4239a9424c7dd391bd2204f1d39',1,'plf2ops_t']]],
   ['mjdtojd',['MJDtoJD',['../qsastime__extra_8c.html#a3dd692ef315d653adec07cf79bbafab4',1,'qsastime_extra.c']]],
   ['mlo',['mlo',['../plot3d_8c.html#ab5532b964e2d395548e895f4a6b7616e',1,'plot3d.c']]],
   ['mode',['mode',['../structplplot_1_1__N1.html#affdc3d642e8589ed9146f675c477e031',1,'plplot::_N1::mode()'],['../structPLOptionTable.html#a813692b51c558740a63d3903bb226470',1,'PLOptionTable::mode()']]],
@@ -119,7 +129,7 @@ var searchData=
   ['mt',['mt',['../mt19937ar_8c.html#aff3cefd0011b487c57a7af7cb3bc499f',1,'mt19937ar.c']]],
   ['mti',['mti',['../mt19937ar_8c.html#a0893639c022032e006e5b13378f7b4b2',1,'mt19937ar.c']]],
   ['mtype',['mtype',['../structcdImageStruct.html#ade89f12f41d1dbb93d77d8df2c4d1531',1,'cdImageStruct']]],
-  ['mul',['mul',['../structplf2ops__t.html#a7396cd485691b520bcfde0021bca26fb',1,'plf2ops_t']]],
+  ['mul',['mul',['../structplf2ops__t.html#aff1cc82f307de8d430f496c07a9143e7',1,'plf2ops_t']]],
   ['mutex',['mutex',['../classQtPLDriver.html#a970f4f57f9b1cf27d5d4c500298a5091',1,'QtPLDriver']]],
   ['myct_5ffuncstr',['myct_funcstr',['../plplotluacLUA__wrap_8c.html#aa5ede8a2565e24ed4df2e0896f47036c',1,'plplotluacLUA_wrap.c']]],
   ['myl',['myL',['../plplotluacLUA__wrap_8c.html#a9917af03e350a440311193fb9099c720',1,'plplotluacLUA_wrap.c']]],
