@@ -1,4 +1,4 @@
-#  Copyright (C) 2001-2016 Alan W. Irwin
+#  Copyright (C) 2001-2017 Alan W. Irwin
 
 #  plshade demo, using color fill.
 #
@@ -37,7 +37,7 @@ def mypltr(x, y, data):
     result0 = data[0] * x + data[1] * y + data[2]
     result1 = data[3] * x + data[4] * y + data[5]
     return array((result0, result1))
-		
+
 def main(w):
 
     fill_width = 2.
@@ -60,9 +60,9 @@ def main(w):
 
     # Set up data array
 
-    x = (arange(NX) - (NX/2)) / float(NX/2)
+    x = (arange(NX) - (NX//2)) / float(NX//2)
     x.shape = (-1,1)
-    y = (arange(NY) - (NY/2)) / float(NY/2) - 1.
+    y = (arange(NY) - (NY//2)) / float(NY//2) - 1.
     zz = -sin(7.*x) * cos(7.*y) + x*x - y*y
     ww = -cos(7.*x) * sin(7.*y) + 2.*x*y
 
@@ -78,7 +78,7 @@ def main(w):
     # and mypltr(i,j,tr)[1] is only function of j.
     xg0 = mypltr(arange(NX),0,tr)[0]
     yg0 = mypltr(0,arange(NY),tr)[1]
-	
+
     # Build the 1-d coord arrays.
 
     distort = .4
@@ -170,7 +170,7 @@ def main(w):
     w.plcol0(1)
     w.plbox( "bcnst", 0.0, 0, "bcnstv", 0.0, 0 )
     w.plcol0(2)
-	
+
     w.pllab( "distance", "altitude", "Bogon density" )
 
     # Plot using 2d coordinate transform
